@@ -153,7 +153,7 @@ class Resource(BASE, RallyBase):
 
 
 class Task(BASE, RallyBase):
-    """Represents a Benchmark task."""
+    """Represents a task."""
     __tablename__ = "tasks"
     __table_args__ = (
         sa.Index("task_uuid", "uuid", unique=True),
@@ -163,12 +163,6 @@ class Task(BASE, RallyBase):
 
     id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
     uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
-    status = sa.Column(sa.Enum(*list(consts.TaskStatus),
-                       name="enum_tasks_status"),
-                       default=consts.TaskStatus.INIT,
-                       nullable=False)
-    verification_log = sa.Column(sa.Text, default="")
-    tag = sa.Column(sa.String(64), default="")
 
     deployment_uuid = sa.Column(
         sa.String(36),
@@ -183,25 +177,221 @@ class Task(BASE, RallyBase):
         primaryjoin=(deployment_uuid == Deployment.uuid),
     )
 
+    input_task = sa.Column(sa.Text, default="")
+    title = sa.Column(sa.String(64), default="")
+    description = sa.Column(sa.Text, default="")
 
-class TaskResult(BASE, RallyBase):
-    __tablename__ = "task_results"
-    __table_args__ = ()
+    validation_result = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
+
+    validation_duration = sa.Column(sa.Float)
+    task_duration = sa.Column(sa.Float)
+    pass_sla = sa.Column(sa.Boolean)
+
+    status = sa.Column(sa.Enum(*list(consts.TaskStatus),
+                       name="enum_tasks_status"),
+                       default=consts.TaskStatus.INIT,
+                       nullable=False)
+
+
+class Subtask(BASE, RallyBase):
+    __tablename__ = "subtasks"
+    __table_args__ = (
+        sa.Index("subtask_uuid", "uuid", unique=True),
+        sa.Index("subtask_status", "status"),
+    )
 
     id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
 
-    key = sa.Column(sa_types.MutableJSONEncodedDict, nullable=False)
-    data = sa.Column(sa_types.BigMutableJSONEncodedDict, nullable=False)
+    task_uuid = sa.Column(
+        sa.String(36),
+        sa.ForeignKey(Task.uuid),
+        nullable=False,
+    )
 
-    task_uuid = sa.Column(sa.String(36), sa.ForeignKey("tasks.uuid"))
-    task = sa.orm.relationship(Task,
-                               backref=sa.orm.backref("results"),
-                               foreign_keys=task_uuid,
-                               primaryjoin="TaskResult.task_uuid == Task.uuid")
+    task = sa.orm.relationship(
+        Task,
+        backref=sa.orm.backref("subtasks"),
+        foreign_keys=task_uuid,
+        primaryjoin=(task_uuid == Task.uuid),
+    )
+
+    title = sa.Column(sa.String(64), default="")
+    description = sa.Column(sa.Text, default="")
+
+    context = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    sla = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    run_in_parallel = sa.Column(sa.Boolean, default=False, nullable=False)
+    duration = sa.Column(sa.Float)
+    pass_sla = sa.Column(sa.Boolean)
+
+    status = sa.Column(sa.Enum(*list(consts.SubtaskStatus),
+                       name="enum_subtasks_status"),
+                       default=consts.SubtaskStatus.RUNNING,
+                       nullable=False)
+
+
+class Workload(BASE, RallyBase):
+    __tablename__ = "workloads"
+    __table_args__ = (
+        sa.Index("workload_uuid", "uuid", unique=True),
+    )
+
+    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
+
+    task_uuid = sa.Column(
+        sa.String(36),
+        sa.ForeignKey(Task.uuid),
+        nullable=False,
+    )
+
+    subtask_uuid = sa.Column(
+        sa.String(36),
+        sa.ForeignKey(Subtask.uuid),
+        nullable=False,
+    )
+
+    subtask = sa.orm.relationship(
+        Subtask,
+        backref=sa.orm.backref("workloads"),
+        foreign_keys=subtask_uuid,
+        primaryjoin=(subtask_uuid == Subtask.uuid),
+    )
+
+    name = sa.Column(sa.String(64), nullable=False)
+    description = sa.Column(sa.Text, default="")
+    position = sa.Column(sa.Integer, default=0, nullable=False)
+
+    runner = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    runner_type = sa.Column(sa.String(64), nullable=False)
+
+    context = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    sla = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    args = sa.Column(
+        sa_types.JSONEncodedDict, default={}, nullable=False)
+
+    hooks = sa.Column(
+        sa_types.JSONEncodedList, default=[], nullable=False)
+
+    sla_results = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
+
+    context_execution = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
+
+    start_time = sa.Column(sa.DateTime, default=lambda: timeutils.utcnow())
+
+    load_duration = sa.Column(sa.Float, default=0)
+    full_duration = sa.Column(sa.Float, default=0)
+    min_duration = sa.Column(sa.Float, default=0)
+    max_duration = sa.Column(sa.Float, default=0)
+    total_iteration_count = sa.Column(sa.Integer, default=0)
+    failed_iteration_count = sa.Column(sa.Integer, default=0)
+
+    statistics = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
+
+    pass_sla = sa.Column(sa.Boolean)
+    _profiling_data = sa.Column(sa.Text, default="")
+
+
+class WorkloadData(BASE, RallyBase):
+    __tablename__ = "workloaddata"
+    __table_args__ = (
+        sa.Index("workload_data_uuid", "uuid", unique=True),
+    )
+
+    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
+
+    task_uuid = sa.Column(
+        sa.String(36),
+        sa.ForeignKey(Task.uuid),
+        nullable=False,
+    )
+
+    workload_uuid = sa.Column(
+        sa.String(36),
+        sa.ForeignKey(Workload.uuid),
+        nullable=False,
+    )
+
+    workload = sa.orm.relationship(
+        Workload,
+        backref=sa.orm.backref("workload_data"),
+        foreign_keys=workload_uuid,
+        primaryjoin=(workload_uuid == Workload.uuid),
+    )
+
+    chunk_order = sa.Column(sa.Integer, nullable=False)
+    iteration_count = sa.Column(sa.Integer, nullable=False)
+    failed_iteration_count = sa.Column(sa.Integer, nullable=False)
+    chunk_size = sa.Column(sa.Integer, nullable=False)
+    compressed_chunk_size = sa.Column(sa.Integer, nullable=False)
+    started_at = sa.Column(sa.DateTime, default=lambda: timeutils.utcnow(),
+                           nullable=False)
+    finished_at = sa.Column(sa.DateTime, default=lambda: timeutils.utcnow(),
+                            nullable=False)
+    # chunk_data = sa.Column(sa.Text, nullable=False)
+    chunk_data = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
+
+
+class Tag(BASE, RallyBase):
+    __tablename__ = "tags"
+    __table_args__ = (
+        sa.Index("d_type_tag", "uuid", "type", "tag", unique=True),
+    )
+
+    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
+
+    type = sa.Column(sa.String(36), nullable=False)
+
+    tag = sa.Column(sa.String(255), nullable=False)
+
+
+class Verifier(BASE, RallyBase):
+    """Represents a verifier."""
+
+    __tablename__ = "verifiers"
+    __table_args__ = (
+        sa.Index("verifier_uuid", "uuid", unique=True),
+    )
+
+    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
+
+    name = sa.Column(sa.String(255), unique=True)
+    description = sa.Column(sa.Text)
+
+    type = sa.Column(sa.String(255), nullable=False)
+    namespace = sa.Column(sa.String(255))
+
+    source = sa.Column(sa.String(255))
+    version = sa.Column(sa.String(255))
+    system_wide = sa.Column(sa.Boolean)
+
+    status = sa.Column(sa.String(36), default=consts.VerifierStatus.INIT,
+                       nullable=False)
+
+    extra_settings = sa.Column(sa_types.MutableJSONEncodedDict)
 
 
 class Verification(BASE, RallyBase):
-    """Represents a verifier result."""
+    """Represents a verification."""
 
     __tablename__ = "verifications"
     __table_args__ = (
@@ -211,36 +401,27 @@ class Verification(BASE, RallyBase):
     id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
     uuid = sa.Column(sa.String(36), default=UUID, nullable=False)
 
-    deployment_uuid = sa.Column(
-        sa.String(36),
-        sa.ForeignKey(Deployment.uuid),
-        nullable=False,
-    )
+    verifier_uuid = sa.Column(sa.String(36),
+                              sa.ForeignKey(Verifier.uuid),
+                              nullable=False)
+    deployment_uuid = sa.Column(sa.String(36),
+                                sa.ForeignKey(Deployment.uuid),
+                                nullable=False)
 
-    status = sa.Column(sa.Enum(*list(consts.TaskStatus),
-                       name="enum_tasks_status"),
-                       default=consts.TaskStatus.INIT,
+    run_args = sa.Column(sa_types.MutableJSONEncodedDict)
+
+    status = sa.Column(sa.String(36), default=consts.VerificationStatus.INIT,
                        nullable=False)
-    set_name = sa.Column(sa.String(20))
 
-    tests = sa.Column(sa.Integer, default=0)
-    # TODO(andreykurilin): remove this variable, when rally will support db
-    #   migrations. Reason: It is not used anywhere :)
-    errors = sa.Column(sa.Integer, default=0)
+    tests_count = sa.Column(sa.Integer, default=0)
     failures = sa.Column(sa.Integer, default=0)
-    time = sa.Column(sa.Float, default=0.0)
+    skipped = sa.Column(sa.Integer, default=0)
+    success = sa.Column(sa.Integer, default=0)
+    unexpected_success = sa.Column(sa.Integer, default=0)
+    expected_failures = sa.Column(sa.Integer, default=0)
+    tests_duration = sa.Column(sa.Float, default=0.0)
 
-
-class VerificationResult(BASE, RallyBase):
-    __tablename__ = "verification_results"
-    __table_args__ = ()
-
-    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
-
-    verification_uuid = sa.Column(sa.String(36),
-                                  sa.ForeignKey("verifications.uuid"))
-
-    data = sa.Column(sa_types.BigMutableJSONEncodedDict, nullable=False)
+    tests = sa.Column(sa_types.MutableJSONEncodedDict, default={})
 
 
 class Worker(BASE, RallyBase):
