@@ -14,7 +14,6 @@
 #    under the License.
 
 import collections
-import json
 import uuid
 
 from rally.common import db
@@ -384,12 +383,15 @@ class Task(object):
             self._update({"status": status})
 
     def update_verification_log(self, log):
-        self._update({"verification_log": json.dumps(log)})
+        self._update({"validation_result": log})
 
     def set_failed(self, etype, msg, etraceback):
         self._update({"status": consts.TaskStatus.FAILED,
-                      "verification_log": json.dumps(
-                          {"etype": etype, "msg": msg, "trace": etraceback})})
+                      "validation_result": {
+                          "etype": etype, "msg": msg, "trace": etraceback}})
+
+    def add_subtask(self, **subtask):
+        return Subtask(self.task["uuid"], **subtask)
 
     def get_results(self):
         return db.task_result_get_all_by_uuid(self.task["uuid"])
@@ -518,9 +520,6 @@ class Task(object):
             extended.append(scenario)
         return extended
 
-    def append_results(self, key, value):
-        db.task_result_create(self.task["uuid"], key, value)
-
     def delete(self, status=None):
         db.task_delete(self.task["uuid"], status=status)
 
@@ -545,3 +544,35 @@ class Task(object):
                       if soft else consts.TaskStatus.ABORTING)
         self.update_status(new_status, allowed_statuses=(
             consts.TaskStatus.RUNNING, consts.TaskStatus.SOFT_ABORTING))
+
+
+class Subtask(object):
+    """Represents a subtask object."""
+
+    def __init__(self, task_uuid, **attributes):
+        self.subtask = db.subtask_create(task_uuid, **attributes)
+
+    def __getitem__(self, key):
+        return self.subtask[key]
+
+    def add_workload(self, key):
+        return Workload(self.subtask["task_uuid"],
+                        self.subtask["uuid"], key)
+
+
+class Workload(object):
+    """Represents a workload object."""
+
+    def __init__(self, task_uuid, subtask_uuid, key):
+        self.workload = db.workload_create(task_uuid, subtask_uuid, key)
+
+    def __getitem__(self, key):
+        return self.workload[key]
+
+    def add_workload_data(self, chunk_order, workload_data):
+        db.workload_data_create(self.workload["task_uuid"],
+                                self.workload["uuid"], chunk_order,
+                                workload_data)
+
+    def set_results(self, data):
+        db.workload_set_results(self.workload["uuid"], data)
