@@ -158,7 +158,7 @@ class ChecksumMismatch(RallyException):
 
 
 class InvalidAdminException(InvalidArgumentsException):
-    msg_fmt = _("user %(username)s doesn't have 'admin' role")
+    msg_fmt = _("user '%(username)s' doesn't have 'admin' role")
 
 
 class InvalidEndpointsException(InvalidArgumentsException):
@@ -255,4 +255,8 @@ class SSHError(RallyException):
 
 class InvalidConnectionString(RallyException):
     msg_fmt = _("The connection string is not valid: %(message)s. Please "
-                "check your connection string.")
\ No newline at end of file
+                "check your connection string.")
+
+
+class DowngradeNotSupported(RallyException):
+    msg_fmt = _("Database schema downgrade is not supported.")
