@@ -319,7 +319,7 @@ class Keystone(OSClient):
             from keystoneauth1 import plugin
             kw["auth_url"] = sess.get_endpoint(interface=plugin.AUTH_INTERFACE)
         if self.credential.endpoint_type:
-            kw["endpoint_type"] = self.credential.endpoint_type
+            kw["interface"] = self.credential.endpoint_type
         return client.Client(**kw)
 
 
@@ -354,13 +354,19 @@ class Neutron(OSClient):
         """Return neutron client."""
         from neutronclient.neutron import client as neutron
 
-        client = neutron.Client(self.choose_version(version),
-                                session=self.keystone.get_session()[0],
-                                endpoint_url=self._get_endpoint(service_type))
+        kw_args = {}
+        if self.credential.endpoint_type:
+            kw_args["endpoint_type"] = self.credential.endpoint_type
+
+        client = neutron.Client(
+            self.choose_version(version),
+            session=self.keystone.get_session()[0],
+            endpoint_override=self._get_endpoint(service_type),
+            **kw_args)
         return client
 
 
-@configure("glance", default_version="1", default_service_type="image",
+@configure("glance", default_version="2", default_service_type="image",
            supported_versions=["1", "2"])
 class Glance(OSClient):
     def create_client(self, version=None, service_type=None):
@@ -382,9 +388,12 @@ class Heat(OSClient):
         """Return heat client."""
         from heatclient import client as heat
 
-        client = heat.Client(self.choose_version(version),
-                             session=self.keystone.get_session()[0],
-                             endpoint=self._get_endpoint(service_type))
+        client = heat.Client(
+            self.choose_version(version),
+            session=self.keystone.get_session()[0],
+            # Remove endpoint once requirement is python-heatclient>=1.6
+            endpoint=self._get_endpoint(service_type),
+            endpoint_override=self._get_endpoint(service_type))
         return client
 
 
@@ -631,22 +640,6 @@ class Monasca(OSClient):
         return client
 
 
-@configure("cue", default_version="1", default_service_type="message-broker")
-class Cue(OSClient):
-    def create_client(self, service_type=None):
-        """Return cue client."""
-        from cueclient.v1 import client as cue
-
-        version = self.choose_version()
-        api_url = self._get_endpoint(service_type)
-        api_url += "v%s" % version
-
-        session = self.keystone.get_session()[0]
-        endpoint_type = self.credential.endpoint_type
-
-        return cue.Client(session=session, interface=endpoint_type)
-
-
 @configure("senlin", default_version="1", default_service_type="clustering",
            supported_versions=["1"])
 class Senlin(OSClient):
