@@ -22,6 +22,7 @@ from six.moves import queue as Queue
 
 from rally.common import utils
 from rally import consts
+from rally import exceptions
 from rally.task import runner
 from rally.task import utils as butils
 
@@ -156,6 +157,18 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
         "additionalProperties": False
     }
 
+    @classmethod
+    def validate(cls, config):
+        """Validates runner's part of task config."""
+        super(ConstantScenarioRunner, cls).validate(config)
+        if config.get("concurrency", 1) > config.get("times", 1):
+            raise exceptions.ValidationError(
+                "Parameter 'concurrency' means a number of parallel executions"
+                "of iterations. Parameter 'times' means total number of "
+                "iteration executions. It is redundant (and restricted) to "
+                "have number of parallel iterations bigger then total number "
+                "of iterations.")
+
     def _run_scenario(self, cls, method_name, context, args):
         """Runs the specified benchmark scenario with given arguments.
 
