@@ -23,11 +23,12 @@ from rally.common import logging
 from rally.common.plugin import discover
 from rally.common import utils
 from rally.plugins.openstack.cleanup import base
+from rally.plugins.openstack.scenarios.cinder import utils as cinder_utils
 from rally.plugins.openstack.scenarios.fuel import utils as futils
 from rally.plugins.openstack.scenarios.keystone import utils as kutils
 from rally.plugins.openstack.scenarios.nova import utils as nova_utils
+from rally.plugins.openstack.services.identity import identity
 from rally.plugins.openstack.wrappers import glance as glance_wrapper
-from rally.plugins.openstack.wrappers import keystone as keystone_wrapper
 from rally.task import utils as task_utils
 
 CONF = cfg.CONF
@@ -184,6 +185,14 @@ class NovaServer(base.ResourceManager):
         super(NovaServer, self).delete()
 
 
+@base.resource("nova", "server_groups", order=next(_nova_order),
+               tenant_resource=True)
+class NovaServerGroups(base.ResourceManager):
+    def list(self):
+        return [r for r in self._manager().list()
+                if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
+
+
 @base.resource("nova", "floating_ips", order=next(_nova_order))
 class NovaFloatingIPs(SynchronizedDeletion, base.ResourceManager):
 
@@ -265,10 +274,16 @@ class NovaNetworks(SynchronizedDeletion, base.ResourceManager):
 @base.resource("nova", "aggregates", order=next(_nova_order),
                admin_required=True, perform_for_admin_only=True)
 class NovaAggregate(SynchronizedDeletion, base.ResourceManager):
+
     def list(self):
         return [r for r in self._manager().list()
                 if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
 
+    def delete(self):
+        for host in self.raw_resource.hosts:
+            self.raw_resource.remove_host(host)
+        super(NovaAggregate, self).delete()
+
 
 # EC2
 
@@ -371,14 +386,36 @@ class NeutronV1Pool(NeutronLbaasV1Mixin):
     pass
 
 
+class NeutronLbaasV2Mixin(NeutronMixin):
+
+    def list(self):
+        if self.supports_extension("lbaasv2"):
+            return super(NeutronLbaasV2Mixin, self).list()
+        return []
+
+
+@base.resource("neutron", "loadbalancer", order=next(_neutron_order),
+               tenant_resource=True)
+class NeutronV2Loadbalancer(NeutronLbaasV2Mixin):
+
+    def is_deleted(self):
+        try:
+            self._manager().show_loadbalancer(self.id())
+        except Exception as e:
+            return getattr(e, "status_code", 400) == 404
+
+        return False
+
+
 @base.resource("neutron", "port", order=next(_neutron_order),
                tenant_resource=True)
 class NeutronPort(NeutronMixin):
 
     def delete(self):
-        if (self.raw_resource["device_owner"] == "network:router_interface" or
-                self.raw_resource["device_owner"] ==
-                "network:router_interface_distributed"):
+        if (self.raw_resource["device_owner"] in
+            ("network:router_interface",
+             "network:router_interface_distributed",
+             "network:ha_router_replicated_interface")):
             self._manager().remove_interface_router(
                 self.raw_resource["device_id"],
                 {"port_id": self.raw_resource["id"]})
@@ -446,6 +483,15 @@ class CinderVolumeBackup(base.ResourceManager):
     pass
 
 
+@base.resource("cinder", "volume_types", order=next(_cinder_order),
+               admin_required=True, perform_for_admin_only=True)
+class CinderVolumeType(base.ResourceManager):
+    def list(self):
+        return [r for r in self._manager().list()
+                if utils.name_matches_object(r.name,
+                                             cinder_utils.CinderScenario)]
+
+
 @base.resource("cinder", "volume_snapshots", order=next(_cinder_order),
                tenant_resource=True)
 class CinderVolumeSnapshot(base.ResourceManager):
@@ -736,10 +782,32 @@ class SwiftContainer(SwiftMixin):
 
 # MISTRAL
 
-@base.resource("mistral", "workbooks", order=1100, tenant_resource=True)
-class MistralWorkbooks(SynchronizedDeletion, base.ResourceManager):
+_mistral_order = get_order(1100)
+
+
+class MistralMixin(SynchronizedDeletion, base.ResourceManager):
+
     def delete(self):
-        self._manager().delete(self.raw_resource.name)
+        self._manager().delete(self.raw_resource["id"])
+
+
+@base.resource("mistral", "workbooks", order=next(_mistral_order),
+               tenant_resource=True)
+class MistralWorkbooks(MistralMixin):
+    def delete(self):
+        self._manager().delete(self.raw_resource["name"])
+
+
+@base.resource("mistral", "workflows", order=next(_mistral_order),
+               tenant_resource=True)
+class MistralWorkflows(MistralMixin):
+    pass
+
+
+@base.resource("mistral", "executions", order=next(_mistral_order),
+               tenant_resource=True)
+class MistralExecutions(MistralMixin):
+    pass
 
 
 # MURANO
@@ -851,7 +919,7 @@ _keystone_order = get_order(9000)
 class KeystoneMixin(SynchronizedDeletion):
 
     def _manager(self):
-        return keystone_wrapper.wrap(getattr(self.admin, self._service)())
+        return identity.Identity(self.admin)
 
     def delete(self):
         delete_method = getattr(self._manager(), "delete_%s" % self._resource)
