@@ -17,7 +17,6 @@ from rally.common.i18n import _
 from rally.common import logging
 from rally.common import objects
 from rally import osclients
-from rally.plugins.openstack.context.keystone import users
 from rally.task import context
 
 
@@ -29,7 +28,7 @@ LOG = logging.getLogger(__name__)
 #                 validation system and rally CI testing we will make it public
 
 @context.configure(name="existing_users", order=99, hidden=True)
-class ExistingUsers(users.UserContextMixin, context.Context):
+class ExistingUsers(context.Context):
     """This context supports using existing users in Rally.
 
        It uses information about deployment to properly
@@ -45,8 +44,10 @@ class ExistingUsers(users.UserContextMixin, context.Context):
 
     @logging.log_task_wrapper(LOG.info, _("Enter context: `existing_users`"))
     def setup(self):
+        super(ExistingUsers, self).setup()
         self.context["users"] = []
         self.context["tenants"] = {}
+        self.context["user_choice_method"] = "random"
 
         for user in self.config:
             user_credential = objects.Credential(**user)
