@@ -14,11 +14,9 @@
 #    under the License.
 
 import collections
-import random
 import uuid
 
 from oslo_config import cfg
-import six
 
 from rally.common import broker
 from rally.common.i18n import _
@@ -28,7 +26,7 @@ from rally.common import utils as rutils
 from rally import consts
 from rally import exceptions
 from rally import osclients
-from rally.plugins.openstack.wrappers import keystone
+from rally.plugins.openstack.services.identity import identity
 from rally.plugins.openstack.wrappers import network
 from rally.task import context
 from rally.task import utils
@@ -57,56 +55,8 @@ CONF.register_opts(USER_CONTEXT_OPTS,
                                       title="benchmark context options"))
 
 
-class UserContextMixin(object):
-
-    @property
-    def user_choice_method(self):
-        if not hasattr(self, "_user_choice_method"):
-            self._user_choice_method = self.context["config"].get(
-                "users", {}).get("user_choice_method")
-            if self._user_choice_method is None:
-                # NOTE(vponomaryov): consider 'existing_users' context
-                # picking up value for 'user_choice_method'
-                # when it is supported there.
-                # Until it happens we use old "random" approach for
-                # 'existing_users' context.
-                self._user_choice_method = "random"
-        return self._user_choice_method
-
-    def map_for_scenario(self, context_obj):
-        """Pass only context of one user and related to it tenant to scenario.
-
-        We are choosing on each iteration one user
-
-        """
-        scenario_ctx = {}
-        for key, value in six.iteritems(context_obj):
-            if key not in ["users", "tenants"]:
-                scenario_ctx[key] = value
-
-        if self.user_choice_method == "random":
-            user = random.choice(context_obj["users"])
-            tenant = context_obj["tenants"][user["tenant_id"]]
-        else:
-            # Second and last case - 'round_robin'.
-            tenants_amount = len(context_obj["tenants"])
-            # NOTE(amaretskiy): iteration is subtracted by `1' because it
-            #                   starts from `1' but we count from `0'
-            tenant_index = int((context_obj["iteration"] - 1) % tenants_amount)
-            tenant_id = sorted(context_obj["tenants"].keys())[tenant_index]
-            tenant = context_obj["tenants"][tenant_id]
-            users = context_obj["tenants"][tenant_id]["users"]
-            user_index = int(((context_obj["iteration"] - 1) / tenants_amount)
-                             % len(users))
-            user = users[user_index]
-
-        scenario_ctx["user"], scenario_ctx["tenant"] = user, tenant
-
-        return scenario_ctx
-
-
 @context.configure(name="users", order=100)
-class UserGenerator(UserContextMixin, context.Context):
+class UserGenerator(context.Context):
     """Context class for generating temporary users/tenants for benchmarks."""
 
     CONFIG_SCHEMA = {
@@ -143,14 +93,18 @@ class UserGenerator(UserContextMixin, context.Context):
         "users_per_tenant": 1,
         "resource_management_workers":
             cfg.CONF.users_context.resource_management_workers,
-        "project_domain": cfg.CONF.users_context.project_domain,
-        "user_domain": cfg.CONF.users_context.user_domain,
         "user_choice_method": "random",
     }
 
     def __init__(self, context):
+        self.credential = context["admin"]["credential"]
+        project_domain = (self.credential.project_domain_name or
+                          cfg.CONF.users_context.project_domain)
+        user_domain = (self.credential.user_domain_name or
+                       cfg.CONF.users_context.user_domain)
+        self.DEFAULT_CONFIG["project_domain"] = project_domain
+        self.DEFAULT_CONFIG["user_domain"] = user_domain
         super(UserGenerator, self).__init__(context)
-        self.credential = self.context["admin"]["credential"]
 
     def _remove_default_security_group(self):
         """Delete default security group for tenants."""
@@ -211,9 +165,9 @@ class UserGenerator(UserContextMixin, context.Context):
             domain, task_id, i = args
             if "client" not in cache:
                 clients = osclients.Clients(self.credential)
-                cache["client"] = keystone.wrap(clients.keystone())
-            tenant = cache["client"].create_project(
-                self.generate_random_name(), domain)
+                cache["client"] = identity.Identity(
+                    clients, name_generator=self.generate_random_name)
+            tenant = cache["client"].create_project(domain_name=domain)
             tenant_dict = {"id": tenant.id, "name": tenant.name, "users": []}
             tenants.append(tenant_dict)
 
@@ -246,21 +200,23 @@ class UserGenerator(UserContextMixin, context.Context):
             username, password, project_dom, user_dom, tenant_id = args
             if "client" not in cache:
                 clients = osclients.Clients(self.credential)
-                cache["client"] = keystone.wrap(clients.keystone())
+                cache["client"] = identity.Identity(
+                    clients, name_generator=self.generate_random_name)
             client = cache["client"]
-            user = client.create_user(
-                username, password,
-                "%s@email.me" % username,
-                tenant_id, user_dom,
-                default_role=default_role)
+            user = client.create_user(username, password=password,
+                                      project_id=tenant_id,
+                                      domain_name=user_dom,
+                                      default_role=default_role)
             user_credential = objects.Credential(
-                client.auth_url, user.name, password,
+                self.credential.auth_url, user.name, password,
                 self.context["tenants"][tenant_id]["name"],
-                consts.EndpointPermission.USER, client.region_name,
-                project_domain_name=project_dom, user_domain_name=user_dom,
+                consts.EndpointPermission.USER,
+                project_domain_name=project_dom,
+                user_domain_name=user_dom,
                 endpoint_type=self.credential.endpoint_type,
                 https_insecure=self.credential.insecure,
-                https_cacert=self.credential.cacert)
+                https_cacert=self.credential.cacert,
+                region_name=self.credential.region_name)
             users.append({"id": user.id,
                           "credential": user_credential,
                           "tenant_id": tenant_id})
@@ -273,7 +229,7 @@ class UserGenerator(UserContextMixin, context.Context):
         def consume(cache, resource_id):
             if "client" not in cache:
                 clients = osclients.Clients(self.credential)
-                cache["client"] = keystone.wrap(clients.keystone())
+                cache["client"] = identity.Identity(clients)
             getattr(cache["client"], func_name)(resource_id)
         return consume
 
@@ -304,8 +260,10 @@ class UserGenerator(UserContextMixin, context.Context):
     @logging.log_task_wrapper(LOG.info, _("Enter context: `users`"))
     def setup(self):
         """Create tenants and users, using the broker pattern."""
+        super(UserGenerator, self).setup()
         self.context["users"] = []
         self.context["tenants"] = {}
+        self.context["user_choice_method"] = self.config["user_choice_method"]
 
         threads = self.config["resource_management_workers"]
 
