@@ -19,8 +19,8 @@ from rally import consts
 from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
 from rally.plugins.openstack.scenarios.nova import utils as nova_utils
+from rally.plugins.openstack import types
 from rally.task import context
-from rally.task import types
 
 
 LOG = logging.getLogger(__name__)
@@ -59,6 +59,14 @@ class ServerGenerator(context.Context):
             },
             "auto_assign_nic": {
                 "type": "boolean",
+            },
+            "nics": {
+                "type": "array",
+                "properties": {
+                    "net-id": {
+                        "type": "string"
+                    }
+                }
             }
         },
         "required": ["image", "flavor"],
@@ -76,12 +84,13 @@ class ServerGenerator(context.Context):
         flavor = self.config["flavor"]
         auto_nic = self.config["auto_assign_nic"]
         servers_per_tenant = self.config["servers_per_tenant"]
+        kwargs = {"nics": self.config.get("nics", [])}
 
         clients = osclients.Clients(self.context["users"][0]["credential"])
-        image_id = types.ImageResourceType.transform(clients=clients,
-                                                     resource_config=image)
-        flavor_id = types.FlavorResourceType.transform(clients=clients,
-                                                       resource_config=flavor)
+        image_id = types.GlanceImage.transform(clients=clients,
+                                               resource_config=image)
+        flavor_id = types.Flavor.transform(clients=clients,
+                                           resource_config=flavor)
 
         for iter_, (user, tenant_id) in enumerate(rutils.iterate_per_tenants(
                 self.context["users"])):
@@ -102,7 +111,8 @@ class ServerGenerator(context.Context):
 
             servers = nova_scenario._boot_servers(image_id, flavor_id,
                                                   requests=servers_per_tenant,
-                                                  auto_assign_nic=auto_nic)
+                                                  auto_assign_nic=auto_nic,
+                                                  **kwargs)
 
             current_servers = [server.id for server in servers]
 
