@@ -18,24 +18,25 @@ from rally.task import atomic
 from rally.task import validation
 
 
-class Authenticate(scenario.OpenStackScenario):
-    """Benchmark scenarios for the authentication mechanism.
+"""Scenarios for Authentication mechanism."""
 
-    Benchmark scenarios for different types of OpenStack clients like Keystone,
-    Nova etc.
-    """
 
-    @validation.required_openstack(users=True)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.keystone")
+class Keystone(scenario.OpenStackScenario):
+
     @atomic.action_timer("authenticate.keystone")
-    @scenario.configure()
-    def keystone(self):
+    def run(self):
         """Check Keystone Client."""
         self.clients("keystone")
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_glance(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_glance")
+class ValidateGlance(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Glance Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -46,15 +47,19 @@ class Authenticate(scenario.OpenStackScenario):
         """
         glance_client = self.clients("glance")
         image_name = "__intentionally_non_existent_image___"
-        with atomic.ActionTimer(self, "authenticate.validate_glance_%s_times" %
-                                repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_glance_%s_times" % repetitions):
             for i in range(repetitions):
                 list(glance_client.images.list(name=image_name))
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_nova(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_nova")
+class ValidateNova(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Nova Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -63,15 +68,19 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         nova_client = self.clients("nova")
-        with atomic.ActionTimer(self, "authenticate.validate_nova_%s_times" %
-                                repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_nova_%s_times" % repetitions):
             for i in range(repetitions):
                 nova_client.flavors.list()
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_ceilometer(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_ceilometer")
+class ValidateCeilometer(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Ceilometer Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -80,16 +89,19 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         ceilometer_client = self.clients("ceilometer")
-        with atomic.ActionTimer(self,
-                                "authenticate.validate_ceilometer_%s_times"
-                                % repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_ceilometer_%s_times" % repetitions):
             for i in range(repetitions):
                 ceilometer_client.meters.list()
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_cinder(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_cinder")
+class ValidateCinder(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Cinder Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -98,15 +110,19 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         cinder_client = self.clients("cinder")
-        with atomic.ActionTimer(self, "authenticate.validate_cinder_%s_times"
-                                % repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_cinder_%s_times" % repetitions):
             for i in range(repetitions):
                 cinder_client.volume_types.list()
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_neutron(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_neutron")
+class ValidateNeutron(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Neutron Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -115,15 +131,19 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         neutron_client = self.clients("neutron")
-        with atomic.ActionTimer(self, "authenticate.validate_neutron_%s_times"
-                                % repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_neutron_%s_times" % repetitions):
             for i in range(repetitions):
                 neutron_client.list_networks()
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @scenario.configure()
-    def validate_heat(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@scenario.configure(name="Authenticate.validate_heat")
+class ValidateHeat(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Heat Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -132,16 +152,20 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         heat_client = self.clients("heat")
-        with atomic.ActionTimer(self, "authenticate.validate_heat_%s_times"
-                                % repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_heat_%s_times" % repetitions):
             for i in range(repetitions):
                 list(heat_client.stacks.list(limit=0))
 
-    @validation.number("repetitions", minval=1)
-    @validation.required_openstack(users=True)
-    @validation.required_services(consts.Service.MONASCA)
-    @scenario.configure()
-    def validate_monasca(self, repetitions):
+
+@validation.number("repetitions", minval=1)
+@validation.required_openstack(users=True)
+@validation.required_services(consts.Service.MONASCA)
+@scenario.configure(name="Authenticate.validate_monasca")
+class ValidateMonasca(scenario.OpenStackScenario):
+
+    def run(self, repetitions):
         """Check Monasca Client to ensure validation of token.
 
         Creation of the client does not ensure validation of the token.
@@ -150,7 +174,8 @@ class Authenticate(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         monasca_client = self.clients("monasca")
-        with atomic.ActionTimer(self, "authenticate.validate_monasca_%s_times"
-                                % repetitions):
+        with atomic.ActionTimer(
+                self,
+                "authenticate.validate_monasca_%s_times" % repetitions):
             for i in range(repetitions):
-                list(monasca_client.metrics.list(limit=0))
+                list(monasca_client.metrics.list(limit=0))
\ No newline at end of file
