@@ -26,6 +26,7 @@ from rally.task import atomic
 from rally.task import types
 from rally.task import validation
 
+LOG = logging.getLogger(__name__)
 
 """Scenarios for Cinder Volumes."""
 
@@ -67,6 +68,35 @@ class CreateAndListVolume(cinder_utils.CinderScenario,
         self._list_volumes(detailed)
 
 
+@types.convert(image={"type": "glance_image"})
+@validation.image_exists("image", nullable=True)
+@validation.required_services(consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(context={"cleanup": ["cinder"]},
+                    name="CinderVolumes.create_and_get_volume")
+class CreateAndGetVolume(cinder_utils.CinderScenario,
+                         nova_utils.NovaScenario,
+                         glance_utils.GlanceScenario):
+
+    def run(self, size, image=None, **kwargs):
+        """Create a volume and get the volume.
+
+        Measure the "cinder show" command performance.
+
+        :param size: volume size (integer, in GB) or
+                     dictionary, must contain two values:
+                         min - minimum size volumes will be created as;
+                         max - maximum size volumes will be created as.
+        :param image: image to be used to create volume
+        :param kwargs: optional args to create a volume
+        """
+        if image:
+            kwargs["imageRef"] = image
+
+        volume = self._create_volume(size, **kwargs)
+        self._get_volume(volume.id)
+
+
 @validation.required_services(consts.Service.CINDER)
 @validation.required_openstack(users=True)
 @scenario.configure(context={"cleanup": ["cinder"]},
@@ -88,6 +118,43 @@ class ListVolumes(cinder_utils.CinderScenario,
         self._list_volumes(detailed)
 
 
+@validation.required_services(consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(name="CinderVolumes.list_types")
+class ListTypes(cinder_utils.CinderScenario):
+
+    def run(self, search_opts=None, is_public=None):
+        """List all volume types.
+
+        This simple scenario tests the cinder type-list command by listing
+        all the volume types.
+
+        :param search_opts: Options used when search for volume types
+        :param is_public: If query public volume type
+        """
+
+        self._list_types(search_opts, is_public)
+
+
+@validation.required_services(consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(name="CinderVolumes.list_transfers")
+class ListTransfers(cinder_utils.CinderScenario):
+
+    def run(self, detailed=True, search_opts=None):
+        """List all transfers.
+
+        This simple scenario tests the "cinder transfer-list" command by
+        listing all the volume transfers.
+
+        :param detailed: If True, detailed information about volume transfer
+                         should be listed
+        :param search_opts: Search options to filter out volume transfers.
+        """
+
+        self._list_transfers(detailed, search_opts)
+
+
 @types.convert(image={"type": "glance_image"})
 @validation.image_exists("image", nullable=True)
 @validation.required_services(consts.Service.CINDER)
@@ -378,11 +445,7 @@ class CreateSnapshotAndAttachVolume(cinder_utils.CinderScenario,
     def run(self, volume_type=False, size=None, **kwargs):
         """Create volume, snapshot and attach/detach volume.
 
-        This scenario is based on the standalone qaStressTest.py
-        (https://github.com/WaltHP/cinder-stress).
-
-        :param volume_type: Whether or not to specify volume type when creating
-                            volumes.
+        :param volume_type: Name of volume type to use
         :param size: Volume size - dictionary, contains two values:
                         min - minimum size volumes will be created as;
                         max - maximum size volumes will be created as.
@@ -392,16 +455,17 @@ class CreateSnapshotAndAttachVolume(cinder_utils.CinderScenario,
         """
         if size is None:
             size = {"min": 1, "max": 5}
-        selected_type = None
-        volume_types = [None]
 
-        if volume_type:
+        if isinstance(volume_type, bool):
+            LOG.warning("Selecting a random volume type is deprecated"
+                        "as of Rally 0.7.0")
+            volume_types = [None]
             volume_types_list = self.clients("cinder").volume_types.list()
             for s in volume_types_list:
                 volume_types.append(s.name)
-            selected_type = random.choice(volume_types)
+            volume_type = random.choice(volume_types)
 
-        volume = self._create_volume(size, volume_type=selected_type)
+        volume = self._create_volume(size, volume_type=volume_type)
         snapshot = self._create_snapshot(volume.id, False, **kwargs)
 
         server = self.get_random_server()
@@ -702,4 +766,54 @@ class CreateVolumeFromSnapshot(cinder_utils.CinderScenario,
 
         if do_delete:
             self._delete_snapshot(snapshot)
-            self._delete_volume(volume)
\ No newline at end of file
+            self._delete_volume(volume)
+
+
+@types.convert(image={"type": "glance_image"})
+@validation.image_exists("image", nullable=True)
+@validation.required_services(consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(context={"cleanup": ["cinder"]},
+                    name="CinderVolumes.create_volume_"
+                    "and_update_readonly_flag")
+class CreateVolumeAndUpdateReadonlyFlag(cinder_utils.CinderScenario,
+                                        glance_utils.GlanceScenario):
+
+    def run(self, size, image=None, read_only=True, **kwargs):
+        """Create a volume and then update its readonly flag.
+
+        :param size: volume size (integer, in GB)
+        :param image: image to be used to create volume
+        :param read_only:The value to indicate whether to update volume to
+            read-only access mode
+        :param kwargs: optional args to create a volume
+        """
+        if image:
+            kwargs["imageRef"] = image
+        volume = self._create_volume(size, **kwargs)
+        self._update_readonly_flag(volume.id, read_only)
+
+
+@types.convert(image={"type": "glance_image"})
+@validation.image_exists("image", nullable=True)
+@validation.required_services(consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(context={"cleanup": ["cinder"]},
+                    name="CinderVolumes.create_and_accept_transfer")
+class CreateAndAcceptTransfer(cinder_utils.CinderScenario,
+                              glance_utils.GlanceScenario):
+
+    def run(self, size, image=None, **kwargs):
+        """Create a volume transfer, then accept it
+
+        Measure the "cinder transfer-create" and "cinder transfer-accept"
+        command performace.
+        :param size: volume size (integer, in GB)
+        :param image: image to be used to create initial volume
+        :param kwargs: optional args to create a volume
+        """
+        if image:
+            kwargs["imageRef"] = image
+        volume = self._create_volume(size, **kwargs)
+        transfer = self._transfer_create(volume.id)
+        self._transfer_accept(transfer.id, transfer.auth_key)
