@@ -16,6 +16,7 @@
 from rally import consts
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.nova import utils
+from rally.task import atomic
 from rally.task import validation
 
 
@@ -37,3 +38,23 @@ class ListHosts(utils.NovaScenario):
                      availability-zones
         """
         self._list_hosts(zone)
+
+
+@validation.required_services(consts.Service.NOVA)
+@validation.required_openstack(admin=True)
+@scenario.configure(name="NovaHosts.list_and_get_hosts")
+class ListAndGetHosts(utils.NovaScenario):
+
+    def run(self, zone=None):
+        """List all nova hosts,and get detailed information fot this hosts.
+
+        Measure the "nova host-describe" command performance.
+
+        :param zone: List nova hosts in an availability-zone.
+                     None (default value) means list hosts in all
+                     availability-zones
+        """
+        hosts = self._list_hosts(zone)
+        with atomic.ActionTimer(self, "nova.get_%s_hosts" % len(hosts)):
+            for host in hosts:
+                self._get_host(host.host_name, atomic_action=False)
