@@ -16,7 +16,6 @@
 import random
 
 from oslo_config import cfg
-import six
 
 from rally import exceptions
 from rally.plugins.openstack import scenario
@@ -139,7 +138,7 @@ class NovaScenario(scenario.OpenStackScenario):
             server_name, image_id, flavor_id, **kwargs)
 
         self.sleep_between(CONF.benchmark.nova_server_boot_prepoll_delay)
-        server = utils.wait_for(
+        server = utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -151,7 +150,7 @@ class NovaScenario(scenario.OpenStackScenario):
     def _do_server_reboot(self, server, reboottype):
         server.reboot(reboot_type=reboottype)
         self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -213,7 +212,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.rebuild(image, **kwargs)
         self.sleep_between(CONF.benchmark.nova_server_rebuild_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -231,7 +230,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: The server to start and wait to become ACTIVE.
         """
         server.start()
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -249,7 +248,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: The server to stop.
         """
         server.stop()
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["SHUTOFF"],
             update_resource=utils.get_from_manager(),
@@ -268,7 +267,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.rescue()
         self.sleep_between(CONF.benchmark.nova_server_rescue_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["RESCUE"],
             update_resource=utils.get_from_manager(),
@@ -286,7 +285,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.unrescue()
         self.sleep_between(CONF.benchmark.nova_server_unrescue_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -305,7 +304,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.suspend()
         self.sleep_between(CONF.benchmark.nova_server_suspend_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["SUSPENDED"],
             update_resource=utils.get_from_manager(),
@@ -324,7 +323,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.resume()
         self.sleep_between(CONF.benchmark.nova_server_resume_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -343,7 +342,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.pause()
         self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["PAUSED"],
             update_resource=utils.get_from_manager(),
@@ -362,7 +361,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.unpause()
         self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -381,7 +380,7 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.shelve()
         self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["SHELVED_OFFLOADED"],
             update_resource=utils.get_from_manager(),
@@ -400,7 +399,7 @@ class NovaScenario(scenario.OpenStackScenario):
         server.unshelve()
 
         self.sleep_between(CONF.benchmark. nova_server_unshelve_prepoll_delay)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -457,6 +456,30 @@ class NovaScenario(scenario.OpenStackScenario):
                     benchmark.nova_server_delete_poll_interval
                 )
 
+    @atomic.action_timer("nova.create_server_group")
+    def _create_server_group(self, **kwargs):
+        """Create (allocate) a server group.
+
+        :param kwargs: Server group name and policy
+
+        :returns: Nova server group
+        """
+        return self.clients("nova").server_groups.create(**kwargs)
+
+    @atomic.action_timer("nova.list_server_groups")
+    def _list_server_groups(self, all_projects=False):
+        """Get a list of all server groups.
+
+        :param all_projects: If True, display server groups from all
+            projects(Admin only)
+
+        :rtype: list of :class:`ServerGroup`.
+        """
+        if all_projects:
+            return self.admin_clients("nova").server_groups.list(all_projects)
+        else:
+            return self.clients("nova").server_groups.list(all_projects)
+
     @atomic.action_timer("nova.delete_image")
     def _delete_image(self, image):
         """Delete the given image.
@@ -492,7 +515,7 @@ class NovaScenario(scenario.OpenStackScenario):
                                                                server.name)
         image = self.clients("nova").images.get(image_uuid)
         check_interval = CONF.benchmark.nova_server_image_create_poll_interval
-        image = utils.wait_for(
+        image = utils.wait_for_status(
             image,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -571,7 +594,7 @@ class NovaScenario(scenario.OpenStackScenario):
         servers = [s for s in self.clients("nova").servers.list()
                    if s.name.startswith(name_prefix)]
         self.sleep_between(CONF.benchmark.nova_server_boot_prepoll_delay)
-        servers = [utils.wait_for(
+        servers = [utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.
@@ -639,7 +662,7 @@ class NovaScenario(scenario.OpenStackScenario):
     @atomic.action_timer("nova.resize")
     def _resize(self, server, flavor):
         server.resize(flavor)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["VERIFY_RESIZE"],
             update_resource=utils.get_from_manager(),
@@ -650,7 +673,7 @@ class NovaScenario(scenario.OpenStackScenario):
     @atomic.action_timer("nova.resize_confirm")
     def _resize_confirm(self, server, status="ACTIVE"):
         server.confirm_resize()
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=[status],
             update_resource=utils.get_from_manager(),
@@ -662,7 +685,7 @@ class NovaScenario(scenario.OpenStackScenario):
     @atomic.action_timer("nova.resize_revert")
     def _resize_revert(self, server, status="ACTIVE"):
         server.revert_resize()
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=[status],
             update_resource=utils.get_from_manager(),
@@ -677,7 +700,7 @@ class NovaScenario(scenario.OpenStackScenario):
         volume_id = volume.id
         attachment = self.clients("nova").volumes.create_server_volume(
             server_id, volume_id, device)
-        utils.wait_for(
+        utils.wait_for_status(
             volume,
             ready_statuses=["in-use"],
             update_resource=utils.get_from_manager(),
@@ -696,7 +719,7 @@ class NovaScenario(scenario.OpenStackScenario):
 
         self.clients("nova").volumes.delete_server_volume(server_id,
                                                           attachment_id)
-        utils.wait_for(
+        utils.wait_for_status(
             volume,
             ready_statuses=["available"],
             update_resource=utils.get_from_manager(),
@@ -722,7 +745,7 @@ class NovaScenario(scenario.OpenStackScenario):
         server_admin.live_migrate(target_host,
                                   block_migration=block_migration,
                                   disk_over_commit=disk_over_commit)
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["ACTIVE"],
             update_resource=utils.get_from_manager(),
@@ -753,7 +776,7 @@ class NovaScenario(scenario.OpenStackScenario):
                 break
         try:
             new_host = random.choice(
-                [key for key, value in six.iteritems(az.hosts)
+                [key for key, value in az.hosts.items()
                     if key != host and
                     value.get("nova-compute", {}).get("available", False)])
             return new_host
@@ -772,7 +795,7 @@ class NovaScenario(scenario.OpenStackScenario):
         server_admin = self.admin_clients("nova").servers.get(server.id)
         host_pre_migrate = getattr(server_admin, "OS-EXT-SRV-ATTR:host")
         server_admin.migrate()
-        utils.wait_for(
+        utils.wait_for_status(
             server,
             ready_statuses=["VERIFY_RESIZE"],
             update_resource=utils.get_from_manager(),
@@ -805,15 +828,20 @@ class NovaScenario(scenario.OpenStackScenario):
                                          ip_protocol="tcp", cidr="0.0.0.0/0"):
         action_name = ("nova.create_%s_rules" % (rules_per_security_group *
                                                  len(security_groups)))
+        creation_status = True
         with atomic.ActionTimer(self, action_name):
             for i, security_group in enumerate(security_groups):
+                result = True
                 for j in range(rules_per_security_group):
-                        self.clients("nova").security_group_rules.create(
-                            security_group.id,
-                            from_port=(i * rules_per_security_group + j + 1),
-                            to_port=(i * rules_per_security_group + j + 1),
-                            ip_protocol=ip_protocol,
-                            cidr=cidr)
+                    result = self.clients("nova").security_group_rules.create(
+                        security_group.id,
+                        from_port=(i * rules_per_security_group + j + 1),
+                        to_port=(i * rules_per_security_group + j + 1),
+                        ip_protocol=ip_protocol,
+                        cidr=cidr)
+                if not result:
+                    creation_status = False
+        return creation_status
 
     def _update_security_groups(self, security_groups):
         """Update a list of security groups
@@ -840,6 +868,21 @@ class NovaScenario(scenario.OpenStackScenario):
         with atomic.ActionTimer(self, "nova.list_security_groups"):
             return self.clients("nova").security_groups.list()
 
+    @atomic.optional_action_timer("nova.add_server_secgroups")
+    def _add_server_secgroups(self, server, security_group,
+                              atomic_action=False):
+        """add security group to a server.
+
+        :param server: Server object
+        :param security_groups: The name of security group to add.
+        :param atomic_action: True if this is atomic action. added and
+                              handled by the optional_action_timer()
+                              decorator.
+        :returns: An instance of novaclient.base.DictWithMeta
+        """
+        return self.clients("nova").servers.add_security_group(server,
+                                                               security_group)
+
     @atomic.action_timer("nova.list_floating_ips_bulk")
     def _list_floating_ips_bulk(self):
         """List all floating IPs."""
@@ -863,6 +906,14 @@ class NovaScenario(scenario.OpenStackScenario):
         """List hypervisors."""
         return self.admin_clients("nova").hypervisors.list(detailed)
 
+    @atomic.action_timer("nova.statistics_hypervisors")
+    def _statistics_hypervisors(self):
+        """Get hypervisor statistics over all compute nodes.
+
+        :returns: Hypervisor statistics
+        """
+        return self.admin_clients("nova").hypervisors.statistics()
+
     @atomic.optional_action_timer("nova.get_hypervisor")
     def _get_hypervisor(self, hypervisor):
         """Get a specific hypervisor.
@@ -875,6 +926,20 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         return self.admin_clients("nova").hypervisors.get(hypervisor)
 
+    @atomic.optional_action_timer("nova.search_hypervisors")
+    def _search_hypervisors(self, hypervisor_match, servers=False):
+        """List all servers belonging to specific hypervisor.
+
+        :param hypervisor_match: Hypervisor's host name.
+        :param servers: If True, server information is also retrieved.
+        :param atomic_action: True if this is atomic action. added and
+                              handled by the optional_action_timer()
+                              decorator.
+        :returns: Hypervisor object
+        """
+        return self.admin_clients("nova").hypervisors.search(hypervisor_match,
+                                                             servers=servers)
+
     @atomic.action_timer("nova.lock_server")
     def _lock_server(self, server):
         """Lock the given server.
@@ -883,6 +948,18 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         server.lock()
 
+    @atomic.optional_action_timer("nova.uptime_hypervisor")
+    def _uptime_hypervisor(self, hypervisor, atomic_action=False):
+        """Display the uptime of the specified hypervisor.
+
+        :param hypervisor: Hypervisor to get.
+        :param atomic_action: True if this is atomic action. added and
+                              handled by the optional_action_timer()
+                              decorator.
+        :returns: Hypervisor object
+        """
+        return self.admin_clients("nova").hypervisors.uptime(hypervisor)
+
     @atomic.action_timer("nova.unlock_server")
     def _unlock_server(self, server):
         """Unlock the given server.
@@ -964,6 +1041,18 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         return self.admin_clients("nova").hosts.list(zone)
 
+    @atomic.optional_action_timer("nova.get_host")
+    def _get_host(self, host_name):
+        """Describe a specific host.
+
+        :param host_name: host name to get.
+        :param atomic_action: True if this is atomic action. added and
+                              handled by the optional_action_timer()
+                              decorator.
+        :returns: host object
+        """
+        return self.admin_clients("nova").hosts.get(host_name)
+
     @atomic.action_timer("nova.list_services")
     def _list_services(self, host=None, binary=None):
         """return all nova service details
@@ -986,6 +1075,15 @@ class NovaScenario(scenario.OpenStackScenario):
         return self.admin_clients("nova").flavors.create(name, ram, vcpus,
                                                          disk, **kwargs)
 
+    @atomic.action_timer("nova.delete_flavor")
+    def _delete_flavor(self, flavor):
+        """Delete a flavor
+
+        :param flavor: The ID of the :class:`Flavor`
+        :returns: An instance of novaclient.base.TupleWithMeta
+        """
+        return self.admin_clients("nova").flavors.delete(flavor)
+
     @atomic.action_timer("nova.list_flavor_access")
     def _list_flavor_access(self, flavor):
         """List access-rules for non-public flavor.
@@ -994,6 +1092,17 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         return self.admin_clients("nova").flavor_access.list(flavor=flavor)
 
+    @atomic.action_timer("nova.add_tenant_access")
+    def _add_tenant_access(self, flavor, tenant):
+        """Add a tenant to the given flavor access list.
+
+        :param flavor: name or id of the object flavor
+        :param tenant: id of the object tenant
+        :returns: access rules for flavor instance or flavor ID
+        """
+        return self.admin_clients("nova").flavor_access.add_tenant_access(
+            flavor, tenant)
+
     @atomic.action_timer("nova.update_server")
     def _update_server(self, server, description=None):
         """update the server's name and description.
@@ -1028,6 +1137,15 @@ class NovaScenario(scenario.OpenStackScenario):
         return self.admin_clients("nova").aggregates.create(aggregate_name,
                                                             availability_zone)
 
+    @atomic.action_timer("nova.get_aggregate_details")
+    def _get_aggregate_details(self, aggregate):
+        """Get details of the specified aggregate.
+
+        :param aggregate: The aggregate to get details
+        :returns: Detailed information of aggregate
+        """
+        return self.admin_clients("nova").aggregates.get_details(aggregate)
+
     @atomic.action_timer("nova.delete_aggregate")
     def _delete_aggregate(self, aggregate):
         """Delete the specified aggregate.
@@ -1188,3 +1306,14 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         return self.admin_clients("nova").aggregates.remove_host(aggregate,
                                                                  host)
+
+    @atomic.action_timer("nova.aggregate_set_metadata")
+    def _aggregate_set_metadata(self, aggregate, metadata):
+        """Set metadata to an aggregate
+
+        :param aggregate: The aggregate to set metadata to
+        :param metadata: The metadata to be set
+        :return: The aggregate that has the set metadata
+        """
+        return self.admin_clients("nova").aggregates.set_metadata(aggregate,
+                                                                  metadata)
