@@ -14,7 +14,6 @@
 #    under the License.
 
 import abc
-import copy
 
 import jsonschema
 import six
@@ -51,10 +50,10 @@ def configure(name, order, hidden=False):
     return wrapper
 
 
-@plugin.base()
+# TODO(andreykurilin): move it to some common place.
 @six.add_metaclass(abc.ABCMeta)
-class Context(plugin.Plugin, functional.FunctionalMixin,
-              utils.RandomNameGeneratorMixin):
+class BaseContext(plugin.Plugin, functional.FunctionalMixin,
+                  utils.RandomNameGeneratorMixin):
     """This class is a factory for context classes.
 
     Every context class should be a subclass of this class and implement
@@ -89,7 +88,6 @@ class Context(plugin.Plugin, functional.FunctionalMixin,
             #                   however we handle this
             self.config = config
         self.context = ctx
-        self.task = self.context.get("task", {})
 
     def __lt__(self, other):
         return self.get_order() < other.get_order()
@@ -141,18 +139,6 @@ class Context(plugin.Plugin, functional.FunctionalMixin,
         self.context contains information that was passed to scenario
         """
 
-    def map_for_scenario(self, context_obj):
-        """Maps global context to context that is used by scenario.
-
-        This method is run each time to create scenario context which is
-        actually just sub set of global context.
-
-        One of sample where this method is useful is users context.
-        We have set of users and tenants but each scenario should have access
-        to context of single user in single tenant.
-        """
-        return context_obj
-
     def __enter__(self):
         return self
 
@@ -160,6 +146,13 @@ class Context(plugin.Plugin, functional.FunctionalMixin,
         self.cleanup()
 
 
+@plugin.base()
+class Context(BaseContext):
+    def __init__(self, ctx):
+        super(Context, self).__init__(ctx)
+        self.task = self.context.get("task", {})
+
+
 class ContextManager(object):
     """Create context environment and run method inside it."""
 
@@ -169,7 +162,7 @@ class ContextManager(object):
 
     @staticmethod
     def validate(ctx, non_hidden=False):
-        for name, config in six.iteritems(ctx):
+        for name, config in ctx.items():
             Context.get(name).validate(config, non_hidden=non_hidden)
 
     def _get_sorted_context_lst(self):
@@ -197,26 +190,6 @@ class ContextManager(object):
                 LOG.error("Context %s failed during cleanup." % ctx.get_name())
                 LOG.exception(e)
 
-    def map_for_scenario(self):
-        """Returns scenario's specific context from full context.
-
-        Each context class is able to map context object data as it want.
-        E.g. users context will pick one user and it's tenant for each
-        scenario run.
-
-        This method iterates over all context classes used in task
-        and performs transformation of each of them to full context, order of
-        transformation is the same as order of context creation.
-        """
-        # NOTE(boris-42): Original context_obj is read only and should not
-        #                 be modified
-        context_obj = copy.deepcopy(self.context_obj)
-
-        for ctx in self._get_sorted_context_lst():
-            context_obj = ctx.map_for_scenario(context_obj)
-
-        return context_obj
-
     def __enter__(self):
         try:
             self.setup()
