@@ -20,6 +20,7 @@ import time
 import traceback
 
 import jsonschema
+from oslo_config import cfg
 import six
 
 from rally.common.i18n import _
@@ -40,6 +41,14 @@ from rally.task import sla
 
 LOG = logging.getLogger(__name__)
 
+CONF = cfg.CONF
+
+TASK_ENGINE_OPTS = [
+    cfg.IntOpt("raw_result_chunk_size", default=1000, min=1,
+               help="Size of raw result chunk in iterations"),
+]
+CONF.register_opts(TASK_ENGINE_OPTS)
+
 
 class ResultConsumer(object):
     """ResultConsumer class stores results from ScenarioRunner, checks SLA.
@@ -48,11 +57,14 @@ class ResultConsumer(object):
     about started iterations.
     """
 
-    def __init__(self, key, task, runner, abort_on_sla_failure):
+    def __init__(self, key, task, subtask, workload, runner,
+                 abort_on_sla_failure):
         """ResultConsumer constructor.
 
         :param key: Scenario identifier
         :param task: Instance of Task, task to run
+        :param subtask: Instance of Subtask
+        :param workload: Instance of Workload
         :param runner: ScenarioRunner instance that produces results to be
                        consumed
         :param abort_on_sla_failure: True if the execution should be stopped
@@ -61,9 +73,12 @@ class ResultConsumer(object):
 
         self.key = key
         self.task = task
+        self.subtask = subtask
+        self.workload = workload
         self.runner = runner
         self.load_started_at = float("inf")
         self.load_finished_at = 0
+        self.workload_data_count = 0
 
         self.sla_checker = sla.SLAChecker(key["kw"])
         self.hook_executor = hook.HookExecutor(key["kw"], self.task)
@@ -85,6 +100,7 @@ class ResultConsumer(object):
         return self
 
     def _consume_results(self):
+        task_aborted = False
         while True:
             if self.runner.result_queue:
                 results = self.runner.result_queue.popleft()
@@ -95,9 +111,25 @@ class ResultConsumer(object):
                     self.load_finished_at = max(r["duration"] + r["timestamp"],
                                                 self.load_finished_at)
                     success = self.sla_checker.add_iteration(r)
-                    if self.abort_on_sla_failure and not success:
+                    if (self.abort_on_sla_failure and
+                            not success and
+                            not task_aborted):
                         self.sla_checker.set_aborted_on_sla()
                         self.runner.abort()
+                        self.task.update_status(
+                            consts.TaskStatus.SOFT_ABORTING)
+                        task_aborted = True
+
+                # save results chunks
+                chunk_size = CONF.raw_result_chunk_size
+                while len(self.results) >= chunk_size:
+                    results_chunk = self.results[:chunk_size]
+                    self.results = self.results[chunk_size:]
+                    results_chunk.sort(key=lambda x: x["timestamp"])
+                    self.workload.add_workload_data(self.workload_data_count,
+                                                    {"raw": results_chunk})
+                    self.workload_data_count += 1
+
             elif self.is_done.isSet():
                 break
             else:
@@ -125,30 +157,32 @@ class ResultConsumer(object):
                 self.task["uuid"]) == consts.TaskStatus.ABORTED:
             self.sla_checker.set_aborted_manually()
 
-        # NOTE(boris-42): Sort in order of starting instead of order of ending
-        self.results.sort(key=lambda x: x["timestamp"])
-
         load_duration = max(self.load_finished_at - self.load_started_at, 0)
 
         LOG.info("Load duration is: %s" % utils.format_float_to_str(
             load_duration))
         LOG.info("Full runner duration is: %s" %
                  utils.format_float_to_str(self.runner.run_duration))
-        LOG.info("Full duration is %s" % utils.format_float_to_str(
+        LOG.info("Full duration is: %s" % utils.format_float_to_str(
             self.finish - self.start))
 
         results = {
-            "raw": self.results,
             "load_duration": load_duration,
             "full_duration": self.finish - self.start,
             "sla": self.sla_checker.results(),
         }
-        self.runner.send_event(type="load_finished", value=results)
         if "hooks" in self.key["kw"]:
             self.event_thread.join()
             results["hooks"] = self.hook_executor.results()
 
-        self.task.append_results(self.key, results)
+        if self.results:
+            # NOTE(boris-42): Sort in order of starting
+            #                 instead of order of ending
+            self.results.sort(key=lambda x: x["timestamp"])
+            self.workload.add_workload_data(self.workload_data_count,
+                                            {"raw": self.results})
+
+        self.workload.set_results(results)
 
     @staticmethod
     def is_task_in_aborting_status(task_uuid, check_soft=True):
@@ -317,9 +351,11 @@ class TaskEngine(object):
             self._validate_config_syntax(self.config)
             self._validate_config_semantic(self.config)
         except Exception as e:
+            exception_info = json.dumps(traceback.format_exc(), indent=2,
+                                        separators=(",", ": "))
             self.task.set_failed(type(e).__name__,
-                                 str(e),
-                                 json.dumps(traceback.format_exc()))
+                                 str(e), exception_info)
+            LOG.debug(exception_info)
             raise exceptions.InvalidTaskException(str(e))
 
     def _get_runner(self, config):
@@ -356,6 +392,8 @@ class TaskEngine(object):
         self.task.update_status(consts.TaskStatus.RUNNING)
 
         for subtask in self.config.subtasks:
+            subtask_obj = self.task.add_subtask(**subtask.to_dict())
+
             for pos, workload in enumerate(subtask.workloads):
 
                 if ResultConsumer.is_task_in_aborting_status(
@@ -365,18 +403,21 @@ class TaskEngine(object):
                     return
 
                 key = workload.make_key(pos)
+                workload_obj = subtask_obj.add_workload(key)
                 LOG.info("Running benchmark with key: \n%s"
                          % json.dumps(key, indent=2))
                 runner_obj = self._get_runner(workload.runner)
                 context_obj = self._prepare_context(
                     workload.context, workload.name, self.admin)
                 try:
-                    with ResultConsumer(key, self.task, runner_obj,
+                    with ResultConsumer(key, self.task,
+                                        subtask_obj, workload_obj, runner_obj,
                                         self.abort_on_sla_failure):
                         with context.ContextManager(context_obj):
                             runner_obj.run(workload.name, context_obj,
                                            workload.args)
                 except Exception as e:
+                    LOG.debug(traceback.format_exc())
                     LOG.exception(e)
 
         if objects.Task.get_status(
@@ -552,7 +593,7 @@ class TaskConfig(object):
             return [SubTask(s) for s in config["subtasks"]]
         elif self.version == 1:
             subtasks = []
-            for name, v1_workloads in six.iteritems(config):
+            for name, v1_workloads in config.items():
                 for v1_workload in v1_workloads:
                     v2_workload = copy.deepcopy(v1_workload)
                     v2_workload["name"] = name
@@ -579,6 +620,13 @@ class SubTask(object):
                           in config["workloads"]]
         self.context = config.get("context", {})
 
+    def to_dict(self):
+        return {
+            "title": self.title,
+            "description": self.description,
+            "context": self.context,
+        }
+
 
 class Workload(object):
     """Workload -- workload configuration in SubTask.
