@@ -21,6 +21,7 @@ import re
 from glanceclient import exc as glance_exc
 from novaclient import exceptions as nova_exc
 import six
+import yaml
 
 from rally.common.i18n import _
 from rally.common import objects
@@ -30,7 +31,6 @@ from rally import osclients
 from rally.plugins.openstack.context.nova import flavors as flavors_ctx
 from rally.plugins.openstack import types as openstack_types
 from rally.task import types
-from rally.verification.tempest import tempest
 
 # TODO(boris-42): make the validators usable as a functions as well.
 # At the moment validators can only be used as decorators.
@@ -265,7 +265,12 @@ def _get_validated_image(config, clients, param_name):
     try:
         image_id = openstack_types.GlanceImage.transform(
             clients=clients, resource_config=image_args)
-        image = clients.glance().images.get(image=image_id).to_dict()
+        image = clients.glance().images.get(image_id)
+        if hasattr(image, "to_dict"):
+            # NOTE(stpierre): Glance v1 images are objects that can be
+            # converted to dicts; Glance v2 images are already
+            # dict-like
+            image = image.to_dict()
         if not image.get("size"):
             image["size"] = 0
         if not image.get("min_ram"):
@@ -424,59 +429,6 @@ def external_network_exists(config, clients, deployment, network_name):
         return ValidationResult(False, message)
 
 
-@validator
-def tempest_tests_exists(config, clients, deployment):
-    """Validator checks that specified test exists."""
-    args = config.get("args", {})
-
-    if "test_name" in args:
-        tests = [args["test_name"]]
-    else:
-        tests = args.get("test_names", [])
-
-    if not tests:
-        return ValidationResult(False,
-                                _("Parameter 'test_name' or 'test_names' "
-                                  "should be specified."))
-    verifier = tempest.Tempest(
-        deployment["uuid"],
-        source=config.get("context", {}).get("tempest", {}).get("source"))
-    if not verifier.is_installed():
-        try:
-            verifier.install()
-        except tempest.TempestSetupFailure as e:
-            return ValidationResult(False, e)
-    if not verifier.is_configured():
-        verifier.generate_config_file()
-
-    allowed_tests = verifier.discover_tests()
-
-    for i, test in enumerate(tests):
-        if not test.startswith("tempest.api."):
-            tests[i] = "tempest.api." + test
-
-    wrong_tests = set(tests) - allowed_tests
-
-    if wrong_tests:
-        message = (_("One or more tests not found: '%s'") %
-                   "', '".join(sorted(wrong_tests)))
-        return ValidationResult(False, message)
-
-
-@validator
-def tempest_set_exists(config, clients, deployment):
-    """Validator that check that tempest set_name is valid."""
-    set_name = config.get("args", {}).get("set_name")
-
-    if not set_name:
-        return ValidationResult(False, "`set_name` is not specified.")
-
-    if set_name not in (list(consts.TempestTestsSets) +
-                        list(consts.TempestTestsAPI)):
-        message = _("There is no tempest set with name '%s'.") % set_name
-        return ValidationResult(False, message)
-
-
 @validator
 def required_parameters(config, clients, deployment, *required_params):
     """Validator for checking required parameters are specified.
@@ -727,3 +679,30 @@ def validate_heat_template(config, clients, deployment, *param_names):
                 msg = (_("Heat template validation failed on %(path)s. "
                          "Original error message: %(msg)s.") % dct)
                 return ValidationResult(False, msg)
+
+
+@validator
+def workbook_contains_workflow(config, clients, deployment, workbook,
+                               workflow_name):
+    """Validate that workflow exist in workbook when workflow is passed
+
+    :param workbook: parameter containing the workbook definition
+    :param workflow_name: parameter containing the workflow name
+    """
+
+    wf_name = config.get("args", {}).get(workflow_name)
+    if wf_name:
+        wb_path = config.get("args", {}).get(workbook)
+        wb_path = os.path.expanduser(wb_path)
+        file_result = _file_access_ok(config.get("args", {}).get(workbook),
+                                      os.R_OK, workbook)
+        if not file_result.is_valid:
+            return file_result
+
+        with open(wb_path, "r") as wb_def:
+            wb_def = yaml.safe_load(wb_def)
+            if wf_name not in wb_def["workflows"]:
+                return ValidationResult(
+                    False,
+                    "workflow '{}' not found in the definition '{}'".format(
+                        wf_name, wb_def))
