@@ -21,6 +21,8 @@ import json
 import subprocess
 import sys
 
+import six
+
 from rally.cli import cliutils
 from rally.common import objects
 from rally.common.plugin import discover
@@ -31,7 +33,8 @@ from rally import osclients
 class ResourceManager(object):
 
     REQUIRED_SERVICE = None
-    REPR_KEYS = ("id", "name", "tenant_id", "zone", "zoneName", "pool")
+    REPR_KEYS = ("id", "name", "tenant_id", "zone", "zoneName", "pool",
+                 "blob")
 
     def __init__(self, clients):
         self.clients = clients
@@ -91,6 +94,14 @@ class Keystone(ResourceManager):
     def list_roles(self):
         return self.client.roles.list()
 
+    def list_ec2credentials(self):
+        users = self.list_users()
+        ec2_list = []
+        for user in users:
+            ec2_list.extend(
+                self.client.ec2.list(user.id))
+        return ec2_list
+
 
 class Magnum(ResourceManager):
 
@@ -119,6 +130,20 @@ class Magnum(ResourceManager):
         return result
 
 
+class Mistral(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.MISTRAL
+
+    def list_workbooks(self):
+        return self.client.workbooks.list()
+
+    def list_workflows(self):
+        return self.client.workflows.list()
+
+    def list_executions(self):
+        return self.client.executions.list()
+
+
 class Nova(ResourceManager):
 
     REQUIRED_SERVICE = consts.Service.NOVA
@@ -132,9 +157,24 @@ class Nova(ResourceManager):
     def list_floating_ips(self):
         return self.client.floating_ips.list()
 
+    def list_floating_ips_bulk(self):
+        return self.client.floating_ips_bulk.list()
+
     def list_images(self):
         return self.client.images.list()
 
+    def list_aggregates(self):
+        return self.client.aggregates.list()
+
+    def list_hosts(self):
+        return self.client.hosts.list()
+
+    def list_hypervisors(self):
+        return self.client.hypervisors.list()
+
+    def list_agents(self):
+        return self.client.agents.list()
+
     def list_keypairs(self):
         return self.client.keypairs.list()
 
@@ -230,6 +270,12 @@ class Cinder(ResourceManager):
     def list_volume_types(self):
         return self.client.volume_types.list()
 
+    def list_encryption_types(self):
+        return self.client.volume_encryption_types.list()
+
+    def list_transfers(self):
+        return self.client.transfers.list()
+
     def list_volumes(self):
         return self.client.volumes.list(
             search_opts={"all_tenants": True})
@@ -309,7 +355,8 @@ class CloudResources(object):
             manager = cls(self.clients)
             if manager.is_available():
                 resources.extend(manager.get_resources())
-        return sorted(self._deduplicate(resources))
+        return sorted(self._deduplicate(resources),
+                      key=(lambda x: str(type(x)) + repr(x)))
 
     def compare(self, with_list):
         # NOTE(stpierre): Each resource is either a list of 2-tuples,
@@ -364,8 +411,9 @@ def main():
     if args.credentials:
         config = json.load(args.credentials)
     else:
-        config = json.loads(subprocess.check_output(["rally", "deployment",
-                                                     "config"]))
+        out = subprocess.check_output(["rally", "deployment",
+                                       "config"])
+        config = json.loads(out if six.PY2 else out.decode("utf-8"))
         config.update(config.pop("admin"))
         del config["type"]
         if "users" in config:
