@@ -206,7 +206,7 @@ class TaskTestCase(unittest.TestCase):
     def test_sla_check_with_wrong_task_id(self):
         rally = utils.Rally()
         self.assertRaises(utils.RallyCliError,
-                          rally, "task sla_check --uuid %s" % FAKE_TASK_UUID)
+                          rally, "task sla-check --uuid %s" % FAKE_TASK_UUID)
 
     def test_status_with_wrong_task_id(self):
         rally = utils.Rally()
@@ -397,7 +397,7 @@ class TaskTestCase(unittest.TestCase):
         for line in res.splitlines():
             if "finished" in line:
                 task_uuids.append(line.split(" ")[1][:-1])
-        self.assertTrue(len(task_uuids))
+        self.assertGreater(len(task_uuids), 0)
         self.assertIn(task_uuids[0],
                       rally("task list --uuids-only --deployment MAIN"))
 
@@ -563,6 +563,8 @@ class TaskTestCase(unittest.TestCase):
               {"task_file": config.filename,
                "deployment_id": deployment_id})
         results = json.loads(rally("task results"))
+        self.assertEqual(1, len(results),
+                         "Second subtask should not be started")
         iterations_completed = len(results[0]["result"])
         self.assertLess(iterations_completed, times)
 
@@ -582,6 +584,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "max_seconds_per_iteration": 0.01
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -602,6 +614,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "max_seconds_per_iteration": 0.01
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -623,6 +645,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "max_seconds_per_iteration": 0.01
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -644,6 +676,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "failure_rate": {"max": 0.0}
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -664,6 +706,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "failure_rate": {"max": 0.0}
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -685,6 +737,16 @@ class TaskTestCase(unittest.TestCase):
                     "sla": {
                         "failure_rate": {"max": 0.0}
                     }
+                },
+                {
+                    "args": {
+                        "sleep": 0.1
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
                 }
             ]
         }
@@ -883,13 +945,13 @@ class SLATestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(max_seconds_per_iteration=0.001)
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        self.assertRaises(utils.RallyCliError, rally, "task sla_check")
+        self.assertRaises(utils.RallyCliError, rally, "task sla-check")
 
     def test_sla_success(self):
         rally = utils.Rally()
         config = utils.TaskConfig(self._get_sample_task_config())
         rally("task start --task %s" % config.filename)
-        rally("task sla_check")
+        rally("task sla-check")
         expected = [
             {"benchmark": "KeystoneBasic.create_and_list_users",
              "criterion": "failure_rate",
@@ -900,7 +962,7 @@ class SLATestCase(unittest.TestCase):
              "detail": mock.ANY,
              "pos": 0, "status": "PASS"}
         ]
-        data = rally("task sla_check --json", getjson=True)
+        data = rally("task sla-check --json", getjson=True)
         self.assertEqual(expected, data)
 
 
@@ -935,11 +997,11 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
              "pos": 0, "status": "FAIL"}
         ]
         try:
-            rally("task sla_check --json", getjson=True)
+            rally("task sla-check --json", getjson=True)
         except utils.RallyCliError as expected_error:
             self.assertEqual(json.loads(expected_error.output), expected)
         else:
-            self.fail("`rally task sla_check` command should return non-zero "
+            self.fail("`rally task sla-check` command should return non-zero "
                       "exit code")
 
     def _test_broken_context(self, runner):
@@ -963,11 +1025,11 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
              "pos": 0, "status": "FAIL"}
         ]
         try:
-            rally("task sla_check --json", getjson=True)
+            rally("task sla-check --json", getjson=True)
         except utils.RallyCliError as expected_error:
             self.assertEqual(json.loads(expected_error.output), expected)
         else:
-            self.fail("`rally task sla_check` command should return non-zero "
+            self.fail("`rally task sla-check` command should return non-zero "
                       "exit code")
 
     def test_broken_context_with_constant_runner(self):
@@ -1012,20 +1074,20 @@ class SLAPerfDegrTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(max_degradation=1)
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        self.assertRaises(utils.RallyCliError, rally, "task sla_check")
+        self.assertRaises(utils.RallyCliError, rally, "task sla-check")
 
     def test_sla_success(self):
         rally = utils.Rally()
         config = utils.TaskConfig(self._get_sample_task_config())
         rally("task start --task %s" % config.filename)
-        rally("task sla_check")
+        rally("task sla-check")
         expected = [
             {"benchmark": "Dummy.dummy_random_action",
              "criterion": "performance_degradation",
              "detail": mock.ANY,
              "pos": 0, "status": "PASS"},
         ]
-        data = rally("task sla_check --json", getjson=True)
+        data = rally("task sla-check --json", getjson=True)
         self.assertEqual(expected, data)
 
 
@@ -1203,5 +1265,8 @@ class HookTestCase(unittest.TestCase):
         hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5]),
                     self._get_result(hooks_cfg[1], seconds=[3, 6, 9])]
-        self.assertEqual(expected, hook_results)
+        self.assertEqual(
+            expected,
+            sorted(hook_results,
+                   key=lambda i: i["config"]["trigger"]["args"]["unit"]))
         self._assert_results_time(hook_results)
