@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import json
 import os
 import re
@@ -49,6 +50,7 @@ class TestTaskSamples(unittest.TestCase):
                 return True
         return False
 
+    @plugins.ensure_plugins_are_loaded
     def test_task_samples_is_valid(self):
         rally = utils.Rally(force_new_db=True)
         # In TestTaskSamples, Rally API will be called directly (not via
@@ -67,10 +69,15 @@ class TestTaskSamples(unittest.TestCase):
         self.addCleanup(user_ctx.cleanup)
 
         config = deployment["config"]
-        config["users"] = [{
-            "username": ctx["users"][0]["credential"].username,
-            "password": ctx["users"][0]["credential"].password,
-            "tenant_name": ctx["users"][0]["credential"].tenant_name}]
+        user = copy.copy(config["admin"])
+        user["username"] = ctx["users"][0]["credential"].username
+        user["password"] = ctx["users"][0]["credential"].password
+        if "project_name" in config["admin"]:
+            # it is Keystone
+            user["project_name"] = ctx["users"][0]["credential"].tenant_name
+        else:
+            user["tenant_name"] = ctx["users"][0]["credential"].tenant_name
+        config["users"] = [user]
 
         rally("deployment destroy MAIN", write_report=False)
         deployment_cfg = os.path.join(rally.tmp_dir, "new_deployment.json")
@@ -79,7 +86,6 @@ class TestTaskSamples(unittest.TestCase):
         rally("deployment create --name MAIN --filename %s" % deployment_cfg,
               write_report=False)
 
-        plugins.load()
         samples_path = os.path.join(
             os.path.dirname(__file__), os.pardir, os.pardir,
             "samples", "tasks")
