@@ -22,6 +22,7 @@ from watcherclient.common.apiclient import exceptions as watcher_exceptions
 
 from rally.common import utils
 from rally.plugins.openstack.cleanup import resources
+from rally.plugins.openstack.scenarios.cinder import utils as cutils
 from rally.plugins.openstack.scenarios.keystone import utils as kutils
 from rally.plugins.openstack.scenarios.nova import utils as nutils
 from tests.unit import test
@@ -189,6 +190,23 @@ class NovaAggregatesTestCase(test.TestCase):
             [mock.call(r.name, nutils.NovaScenario) for r in aggregates])
 
 
+class NovaServerGroupsTestCase(test.TestCase):
+
+    @mock.patch("%s.base.ResourceManager._manager" % BASE)
+    @mock.patch("rally.common.utils.name_matches_object")
+    def test_list(self, mock_name_matches_object,
+                  mock_resource_manager__manager):
+        server_groups = [mock.MagicMock(name="rally_foo1"),
+                         mock.MagicMock(name="rally_foo2"),
+                         mock.MagicMock(name="foo3")]
+        mock_name_matches_object.side_effect = [False, True, True]
+        mock_resource_manager__manager().list.return_value = server_groups
+        self.assertEqual(server_groups[1:],
+                         resources.NovaServerGroups().list())
+        mock_name_matches_object.assert_has_calls(
+            [mock.call(r.name, nutils.NovaScenario) for r in server_groups])
+
+
 class NovaSecurityGroupTestCase(test.TestCase):
 
     @mock.patch("%s.base.ResourceManager._manager" % BASE)
@@ -416,6 +434,79 @@ class NeutronLbaasV1MixinTestCase(test.TestCase):
         self.assertFalse(neut._manager().list_some_resources.called)
 
 
+class NeutronLbaasV2MixinTestCase(test.TestCase):
+
+    def get_neutron_lbaasv2_mixin(self, extensions=None):
+        if extensions is None:
+            extensions = []
+        neut = resources.NeutronLbaasV2Mixin()
+        neut._service = "neutron"
+        neut._resource = "some_resource"
+        neut._manager = mock.Mock()
+        neut._manager().list_extensions.return_value = {
+            "extensions": [{"alias": ext} for ext in extensions]
+        }
+        return neut
+
+    def test_list_lbaasv2_available(self):
+        neut = self.get_neutron_lbaasv2_mixin(extensions=["lbaasv2"])
+        neut.tenant_uuid = "user_tenant"
+
+        some_resources = [{"tenant_id": neut.tenant_uuid}, {"tenant_id": "a"}]
+        neut._manager().list_some_resources.return_value = {
+            "some_resources": some_resources
+        }
+
+        self.assertEqual([some_resources[0]], list(neut.list()))
+        neut._manager().list_some_resources.assert_called_once_with(
+            tenant_id=neut.tenant_uuid)
+
+    def test_list_lbaasv2_unavailable(self):
+        neut = self.get_neutron_lbaasv2_mixin()
+
+        self.assertEqual([], list(neut.list()))
+        self.assertFalse(neut._manager().list_some_resources.called)
+
+
+class NeutronV2LoadbalancerTestCase(test.TestCase):
+
+    def get_neutron_lbaasv2_lb(self):
+        neutron_lb = resources.NeutronV2Loadbalancer()
+        neutron_lb.raw_resource = {"id": "1", "name": "s_rally"}
+        neutron_lb._manager = mock.Mock()
+        return neutron_lb
+
+    def test_is_deleted_true(self):
+        from neutronclient.common import exceptions as n_exceptions
+        neutron_lb = self.get_neutron_lbaasv2_lb()
+        neutron_lb._manager().show_loadbalancer.side_effect = (
+            n_exceptions.NotFound)
+
+        self.assertTrue(neutron_lb.is_deleted())
+
+        neutron_lb._manager().show_loadbalancer.assert_called_once_with(
+            neutron_lb.id())
+
+    def test_is_deleted_false(self):
+        from neutronclient.common import exceptions as n_exceptions
+        neutron_lb = self.get_neutron_lbaasv2_lb()
+        neutron_lb._manager().show_loadbalancer.return_value = (
+            neutron_lb.raw_resource)
+
+        self.assertFalse(neutron_lb.is_deleted())
+        neutron_lb._manager().show_loadbalancer.assert_called_once_with(
+            neutron_lb.id())
+
+        neutron_lb._manager().show_loadbalancer.reset_mock()
+
+        neutron_lb._manager().show_loadbalancer.side_effect = (
+            n_exceptions.Forbidden)
+
+        self.assertFalse(neutron_lb.is_deleted())
+        neutron_lb._manager().show_loadbalancer.assert_called_once_with(
+            neutron_lb.id())
+
+
 class NeutronPortTestCase(test.TestCase):
 
     def test_delete(self):
@@ -589,30 +680,30 @@ class KeystoneMixinTestCase(test.TestCase):
         kmixin._service = "keystone"
         return kmixin
 
-    @mock.patch("%s.keystone_wrapper.wrap" % BASE)
-    def test_manager(self, mock_wrap):
+    @mock.patch("%s.identity" % BASE)
+    def test_manager(self, mock_identity):
         keystone_mixin = self.get_keystone_mixin()
         keystone_mixin.admin = mock.MagicMock()
-        self.assertEqual(mock_wrap.return_value, keystone_mixin._manager())
-        mock_wrap.assert_called_once_with(
-            keystone_mixin.admin.keystone.return_value)
+        self.assertEqual(mock_identity.Identity.return_value,
+                         keystone_mixin._manager())
+        mock_identity.Identity.assert_called_once_with(
+            keystone_mixin.admin)
 
-    @mock.patch("%s.keystone_wrapper.wrap" % BASE)
-    def test_delete(self, mock_wrap):
+    @mock.patch("%s.identity" % BASE)
+    def test_delete(self, mock_identity):
         keystone_mixin = self.get_keystone_mixin()
         keystone_mixin._resource = "some_resource"
         keystone_mixin.id = lambda: "id_a"
         keystone_mixin.admin = mock.MagicMock()
 
         keystone_mixin.delete()
-        mock_wrap.assert_called_once_with(
-            keystone_mixin.admin.keystone.return_value)
-        mock_wrap().delete_some_resource.assert_called_once_with("id_a")
+        mock_identity.Identity.assert_called_once_with(keystone_mixin.admin)
+        identity_service = mock_identity.Identity.return_value
+        identity_service.delete_some_resource.assert_called_once_with("id_a")
 
-    @mock.patch(
-        "rally.common.utils.name_matches_object")
-    @mock.patch("%s.keystone_wrapper.wrap" % BASE)
-    def test_list(self, mock_wrap, mock_name_matches_object):
+    @mock.patch("rally.common.utils.name_matches_object")
+    @mock.patch("%s.identity" % BASE)
+    def test_list(self, mock_identity, mock_name_matches_object):
         keystone_mixin = self.get_keystone_mixin()
         keystone_mixin._resource = "fake_resource"
         keystone_mixin.admin = mock.MagicMock()
@@ -622,10 +713,12 @@ class KeystoneMixinTestCase(test.TestCase):
                   mock.MagicMock(name="foo3")]
         mock_name_matches_object.side_effect = [True, True, False]
 
-        mock_wrap().list_fake_resources.return_value = result
+        identity_service = mock_identity.Identity.return_value
+
+        identity_service.list_fake_resources.return_value = result
 
         self.assertSequenceEqual(result[:2], keystone_mixin.list())
-        mock_wrap().list_fake_resources.assert_called_once_with()
+        identity_service.list_fake_resources.assert_called_once_with()
 
         mock_name_matches_object.assert_has_calls(
             [mock.call(r.name, kutils.KeystoneScenario) for r in result])
@@ -760,6 +853,36 @@ class ManilaSecurityServiceTestCase(test.TestCase):
             "fake_id")
 
 
+class MistralMixinTestCase(test.TestCase):
+
+    def test_delete(self):
+        mistral = resources.MistralMixin()
+        mistral._service = "mistral"
+        mistral.user = mock.MagicMock()
+        mistral._resource = "some_resources"
+        mistral.raw_resource = {"id": "TEST_ID"}
+        mistral.user.mistral().some_resources.delete.return_value = None
+
+        mistral.delete()
+        mistral.user.mistral().some_resources.delete.assert_called_once_with(
+            "TEST_ID")
+
+
+class MistralWorkbookTestCase(test.TestCase):
+
+    def test_delete(self):
+        mistral = resources.MistralWorkbooks()
+        mistral._service = "mistral"
+        mistral.user = mock.MagicMock()
+        mistral._resource = "some_resources"
+        mistral.raw_resource = {"name": "TEST_NAME"}
+        mistral.user.mistral().some_resources.delete.return_value = None
+
+        mistral.delete()
+        mistral.user.mistral().some_resources.delete.assert_called_once_with(
+            "TEST_NAME")
+
+
 class FuelEnvironmentTestCase(test.TestCase):
 
     def test_id(self):
@@ -919,3 +1042,19 @@ class WatcherActionPlanTestCase(test.TestCase):
 
         self.assertEqual("action_plan", watcher._resource)
         watcher._manager().list.assert_called_once_with(limit=0)
+
+
+class CinderVolumeTypeTestCase(test.TestCase):
+
+    @mock.patch("%s.base.ResourceManager._manager" % BASE)
+    @mock.patch("rally.common.utils.name_matches_object")
+    def test_list(self, mock_name_matches_object,
+                  mock_resource_manager__manager):
+        volume_types = [mock.MagicMock(name="foo1"),
+                        mock.MagicMock(name="rally_foo2"),
+                        mock.MagicMock(name="rally_foo3")]
+        mock_name_matches_object.side_effect = [False, True, True]
+        mock_resource_manager__manager().list.return_value = volume_types
+        self.assertEqual(volume_types[1:], resources.CinderVolumeType().list())
+        mock_name_matches_object.assert_has_calls(
+            [mock.call(r.name, cutils.CinderScenario) for r in volume_types])
