@@ -108,14 +108,15 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         kwargs["fakearg"] = "fakearg"
         return_server = nova_scenario._boot_server("image_id", "flavor_id",
                                                    **kwargs)
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
             check_interval=CONF.benchmark.nova_server_boot_poll_interval,
             timeout=CONF.benchmark.nova_server_boot_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
-        self.assertEqual(self.mock_wait_for.mock.return_value, return_server)
+        self.assertEqual(self.mock_wait_for_status.mock.return_value,
+                         return_server)
 
         expected_kwargs = {"fakearg": "fakearg"}
         if "nics" in kwargs:
@@ -150,7 +151,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._suspend_server(self.server)
         self.server.suspend.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["SUSPENDED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -164,7 +165,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._resume_server(self.server)
         self.server.resume.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -178,7 +179,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._pause_server(self.server)
         self.server.pause.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["PAUSED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -192,7 +193,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._unpause_server(self.server)
         self.server.unpause.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -206,7 +207,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._shelve_server(self.server)
         self.server.shelve.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["SHELVED_OFFLOADED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -220,7 +221,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._unshelve_server(self.server)
         self.server.unshelve.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -234,7 +235,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self.clients("nova").images.get.return_value = self.image
         nova_scenario = utils.NovaScenario(context=self.context)
         return_image = nova_scenario._create_image(self.server)
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.image,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -242,7 +243,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             nova_server_image_create_poll_interval,
             timeout=CONF.benchmark.nova_server_image_create_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
-        self.assertEqual(self.mock_wait_for.mock.return_value, return_image)
+        self.assertEqual(self.mock_wait_for_status.mock.return_value,
+                         return_image)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.create_image")
 
@@ -280,7 +282,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._reboot_server(self.server)
         self.server.reboot.assert_called_once_with(reboot_type="HARD")
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -294,7 +296,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._soft_reboot_server(self.server)
         self.server.reboot.assert_called_once_with(reboot_type="SOFT")
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -308,7 +310,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._rebuild_server(self.server, "img", fakearg="fakearg")
         self.server.rebuild.assert_called_once_with("img", fakearg="fakearg")
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -322,7 +324,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._start_server(self.server)
         self.server.start.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -336,7 +338,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._stop_server(self.server)
         self.server.stop.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["SHUTOFF"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -350,7 +352,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._rescue_server(self.server)
         self.server.rescue.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["RESCUE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -364,7 +366,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._unrescue_server(self.server)
         self.server.unrescue.assert_called_once_with()
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -459,7 +461,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             for i in range(requests)]
         self.clients("nova").servers.create.assert_has_calls(create_calls)
 
-        wait_for_calls = [
+        wait_for_status_calls = [
             mock.call(
                 servers[i],
                 ready_statuses=["ACTIVE"],
@@ -467,7 +469,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                 check_interval=CONF.benchmark.nova_server_boot_poll_interval,
                 timeout=CONF.benchmark.nova_server_boot_timeout)
             for i in range(instances_amount)]
-        self.mock_wait_for.mock.assert_has_calls(wait_for_calls)
+        self.mock_wait_for_status.mock.assert_has_calls(wait_for_status_calls)
 
         self.mock_get_from_manager.mock.assert_has_calls(
             [mock.call() for i in range(instances_amount)])
@@ -584,7 +586,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             status = "ACTIVE"
         else:
             nova_scenario._resize_revert(self.server, status=status)
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=[status],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -636,7 +638,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                                     disk_over_commit=False,
                                     skip_host_check=True)
 
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -679,7 +681,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._migrate(fake_server, skip_host_check=True)
 
-        self.mock_wait_for.mock.assert_called_once_with(
+        self.mock_wait_for_status.mock.assert_called_once_with(
             fake_server,
             ready_statuses=["VERIFY_RESIZE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
@@ -766,6 +768,22 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.list_security_groups")
 
+    def test__add_server_secgroups(self):
+        server = mock.Mock()
+        fake_secgroups = [fakes.FakeSecurityGroup(None, None, 1, "uuid1")]
+
+        nova_scenario = utils.NovaScenario()
+        security_group = fake_secgroups[0]
+        result = nova_scenario._add_server_secgroups(server,
+                                                     security_group.name)
+        self.assertEqual(
+            self.clients("nova").servers.add_security_group.return_value,
+            result)
+        (self.clients("nova").servers.add_security_group.
+            assert_called_once_with(server, security_group.name))
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.add_server_secgroups")
+
     def test__list_keypairs(self):
         nova_scenario = utils.NovaScenario()
         result = nova_scenario._list_keypairs()
@@ -788,6 +806,32 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.create_keypair")
 
+    def test__create_server_group(self):
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._create_server_group(fakeargs="fakeargs")
+        self.assertEqual(
+            self.clients("nova").server_groups.create.return_value,
+            result)
+        self.clients("nova").server_groups.create.assert_called_once_with(
+            fakeargs="fakeargs")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.create_server_group")
+
+    def test__list_server_groups(self):
+        nova_scenario = utils.NovaScenario()
+        result1 = nova_scenario._list_server_groups(all_projects=False)
+        result2 = nova_scenario._list_server_groups(all_projects=True)
+        self.assertEqual(self.clients("nova").server_groups.list.return_value,
+                         result1)
+        admcli = self.admin_clients("nova")
+        self.assertEqual(admcli.server_groups.list.return_value, result2)
+        self.clients("nova").server_groups.list.assert_called_once_with(
+            False)
+        self.admin_clients("nova").server_groups.list.assert_called_once_with(
+            True)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.list_server_groups")
+
     def test__delete_keypair(self):
         nova_scenario = utils.NovaScenario()
         nova_scenario._delete_keypair("fake_keypair")
@@ -841,6 +885,17 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.list_hypervisors")
 
+    def test__statistics_hypervisors(self):
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._statistics_hypervisors()
+        self.assertEqual(
+            self.admin_clients("nova").hypervisors.statistics.return_value,
+            result)
+        (self.admin_clients("nova").hypervisors.statistics.
+            assert_called_once_with())
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.statistics_hypervisors")
+
     def test__get_hypervisor(self):
         hypervisor = mock.Mock()
         nova_scenario = utils.NovaScenario()
@@ -853,6 +908,26 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.get_hypervisor")
 
+    def test__search_hypervisors(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._search_hypervisors("fake_hostname", servers=False)
+
+        self.admin_clients("nova").hypervisors.search.assert_called_once_with(
+            "fake_hostname", servers=False)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.search_hypervisors")
+
+    def test__get_host(self):
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._get_host("host_name")
+        self.assertEqual(
+            self.admin_clients("nova").hosts.get.return_value,
+            result)
+        self.admin_clients("nova").hosts.get.assert_called_once_with(
+            "host_name")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_host")
+
     def test__list_images(self):
         nova_scenario = utils.NovaScenario()
         result = nova_scenario._list_images(detailed=False, fakearg="fakearg")
@@ -1005,6 +1080,20 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.list_flavor_access")
 
+    def test__add_tenant_access(self):
+        tenant = mock.Mock()
+        flavor = mock.Mock()
+        nova_scenario = utils.NovaScenario()
+        admin_clients = self.admin_clients("nova")
+        result = nova_scenario._add_tenant_access(flavor.id, tenant.id)
+        self.assertEqual(
+            admin_clients.flavor_access.add_tenant_access.return_value,
+            result)
+        admin_clients.flavor_access.add_tenant_access.assert_called_once_with(
+            flavor.id, tenant.id)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.add_tenant_access")
+
     def test__create_flavor(self):
         nova_scenario = utils.NovaScenario()
         random_name = "random_name"
@@ -1031,6 +1120,17 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.get_flavor")
 
+    def test__delete_flavor(self):
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._delete_flavor("foo_flavor_id")
+        self.assertEqual(
+            self.admin_clients("nova").flavors.delete.return_value,
+            result)
+        self.admin_clients("nova").flavors.delete.assert_called_once_with(
+            "foo_flavor_id")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.delete_flavor")
+
     def test__update_server(self):
         server = mock.Mock()
         nova_scenario = utils.NovaScenario()
@@ -1081,6 +1181,18 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.delete_aggregate")
 
+    def test_get_aggregate_details(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        result = nova_scenario._get_aggregate_details("fake_aggregate")
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.get_details.return_value,
+            result)
+        self.admin_clients(
+            "nova").aggregates.get_details.assert_called_once_with(
+            "fake_aggregate")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_aggregate_details")
+
     def test_update_aggregate(self):
         aggregate = mock.Mock()
         nova_scenario = utils.NovaScenario(context=self.context)
@@ -1119,3 +1231,26 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             "fake_agg", "fake_host")
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.aggregate_remove_host")
+
+    def test__uptime_hypervisor(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._uptime_hypervisor("fake_hostname")
+
+        self.admin_clients("nova").hypervisors.uptime.assert_called_once_with(
+            "fake_hostname")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.uptime_hypervisor")
+
+    def test_aggregate_set_metadata(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        fake_metadata = {"test_metadata": "true"}
+        result = nova_scenario._aggregate_set_metadata("fake_aggregate",
+                                                       fake_metadata)
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.set_metadata.return_value,
+            result)
+        self.admin_clients(
+            "nova").aggregates.set_metadata.assert_called_once_with(
+            "fake_aggregate", fake_metadata)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.aggregate_set_metadata")
