@@ -22,6 +22,7 @@ import threading
 import jsonschema
 import mock
 
+from rally.common import objects
 from rally import consts
 from rally import exceptions
 from rally.task import engine
@@ -411,7 +412,7 @@ class TaskEngineTestCase(test.TestCase):
             self, mock_scenario_runner, mock_scenario,
             mock_context_manager_setup, mock_context_manager_cleanup,
             mock_result_consumer, mock_task_get_status):
-        task = mock.MagicMock()
+        task = mock.MagicMock(spec=objects.Task)
         config = {
             "a.task": [{"runner": {"type": "a", "b": 1}}],
             "b.task": [{"runner": {"type": "a", "b": 1}}],
@@ -498,6 +499,8 @@ class ResultConsumerTestCase(test.TestCase):
         mock_task_get_status.return_value = consts.TaskStatus.RUNNING
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
 
         results = [
@@ -508,7 +511,7 @@ class ResultConsumerTestCase(test.TestCase):
         runner.result_queue = collections.deque(results)
         runner.event_queue = collections.deque()
         with engine.ResultConsumer(
-                key, task, runner, False) as consumer_obj:
+                key, task, subtask, workload, runner, False) as consumer_obj:
             pass
 
         mock_sla_instance.add_iteration.assert_has_calls([
@@ -536,22 +539,23 @@ class ResultConsumerTestCase(test.TestCase):
         mock_task_get_status.return_value = consts.TaskStatus.RUNNING
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
 
         results = []
         runner.result_queue = collections.deque(results)
         runner.event_queue = collections.deque()
         with engine.ResultConsumer(
-                key, task, runner, False):
+                key, task, subtask, workload, runner, False):
             pass
-        task.append_results.assert_has_calls([mock.call(
-            key, {
-                "raw": [],
-                "full_duration": 1,
-                "sla": mock_sla_results,
-                "load_duration": 0
-            }
-        )], any_order=True)
+
+        self.assertFalse(workload.add_workload_data.called)
+        workload.set_results.assert_called_once_with({
+            "full_duration": 1,
+            "sla": mock_sla_results,
+            "load_duration": 0
+        })
 
     @mock.patch("rally.common.objects.Task.get_status")
     @mock.patch("rally.task.engine.ResultConsumer.wait_and_abort")
@@ -565,16 +569,20 @@ class ResultConsumerTestCase(test.TestCase):
                                                        False]
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
 
         runner.result_queue = collections.deque(
             [[{"duration": 1, "timestamp": 1},
               {"duration": 2, "timestamp": 2}]] * 4)
 
-        with engine.ResultConsumer(key, task, runner, True):
+        with engine.ResultConsumer(key, task, subtask, workload, runner, True):
             pass
 
         self.assertTrue(runner.abort.called)
+        task.update_status.assert_called_once_with(
+            consts.TaskStatus.SOFT_ABORTING)
 
     @mock.patch("rally.task.hook.HookExecutor")
     @mock.patch("rally.common.objects.Task.get_status")
@@ -592,6 +600,8 @@ class ResultConsumerTestCase(test.TestCase):
 
         task = mock.MagicMock()
         mock_task_get_status.return_value = consts.TaskStatus.ABORTED
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
 
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
 
@@ -601,7 +611,7 @@ class ResultConsumerTestCase(test.TestCase):
 
         mock_hook_executor_instance = mock_hook_executor.return_value
 
-        with engine.ResultConsumer(key, task, runner, True):
+        with engine.ResultConsumer(key, task, subtask, workload, runner, True):
             pass
 
         mock_sla_checker.assert_called_once_with(key["kw"])
@@ -621,12 +631,15 @@ class ResultConsumerTestCase(test.TestCase):
                                                        False]
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
         runner.result_queue = collections.deque(
             [[{"duration": 1, "timestamp": 4}]] * 4)
         runner.event_queue = collections.deque()
 
-        with engine.ResultConsumer(key, task, runner, False):
+        with engine.ResultConsumer(key, task, subtask, workload,
+                                   runner, False):
             pass
 
         self.assertEqual(0, runner.abort.call_count)
@@ -642,12 +655,15 @@ class ResultConsumerTestCase(test.TestCase):
         mock_sla_checker.return_value = mock_sla_instance
         key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
         runner.result_queue = collections.deque([1])
         runner.event_queue = collections.deque()
         exc = TestException()
         try:
-            with engine.ResultConsumer(key, task, runner, False):
+            with engine.ResultConsumer(key, task, subtask, workload,
+                                       runner, False):
                 raise exc
         except TestException:
             pass
@@ -655,6 +671,60 @@ class ResultConsumerTestCase(test.TestCase):
         mock_sla_instance.set_unexpected_failure.assert_has_calls(
             [mock.call(exc)])
 
+    @mock.patch("rally.task.engine.CONF")
+    @mock.patch("rally.common.objects.Task.get_status")
+    @mock.patch("rally.task.engine.ResultConsumer.wait_and_abort")
+    @mock.patch("rally.task.sla.SLAChecker")
+    def test_consume_results_chunked(
+            self, mock_sla_checker, mock_result_consumer_wait_and_abort,
+            mock_task_get_status, mock_conf):
+        mock_conf.raw_result_chunk_size = 2
+        mock_sla_instance = mock.MagicMock()
+        mock_sla_checker.return_value = mock_sla_instance
+        mock_task_get_status.return_value = consts.TaskStatus.RUNNING
+        key = {"kw": {"fake": 2}, "name": "fake", "pos": 0}
+        task = mock.MagicMock(spec=objects.Task)
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
+        runner = mock.MagicMock()
+
+        results = [
+            [{"duration": 1, "timestamp": 3},
+             {"duration": 2, "timestamp": 2},
+             {"duration": 3, "timestamp": 3}],
+            [{"duration": 4, "timestamp": 2},
+             {"duration": 5, "timestamp": 3}],
+            [{"duration": 6, "timestamp": 2}],
+            [{"duration": 7, "timestamp": 1}],
+        ]
+
+        runner.result_queue = collections.deque(results)
+        runner.event_queue = collections.deque()
+        with engine.ResultConsumer(
+                key, task, subtask, workload, runner, False) as consumer_obj:
+            pass
+
+        mock_sla_instance.add_iteration.assert_has_calls([
+            mock.call({"duration": 1, "timestamp": 3}),
+            mock.call({"duration": 2, "timestamp": 2}),
+            mock.call({"duration": 3, "timestamp": 3}),
+            mock.call({"duration": 4, "timestamp": 2}),
+            mock.call({"duration": 5, "timestamp": 3}),
+            mock.call({"duration": 6, "timestamp": 2}),
+            mock.call({"duration": 7, "timestamp": 1})])
+
+        self.assertEqual([{"duration": 7, "timestamp": 1}],
+                         consumer_obj.results)
+
+        workload.add_workload_data.assert_has_calls([
+            mock.call(0, {"raw": [{"duration": 2, "timestamp": 2},
+                                  {"duration": 1, "timestamp": 3}]}),
+            mock.call(1, {"raw": [{"duration": 4, "timestamp": 2},
+                                  {"duration": 3, "timestamp": 3}]}),
+            mock.call(2, {"raw": [{"duration": 6, "timestamp": 2},
+                                  {"duration": 5, "timestamp": 3}]}),
+            mock.call(3, {"raw": [{"duration": 7, "timestamp": 1}]})])
+
     @mock.patch("rally.task.engine.LOG")
     @mock.patch("rally.task.hook.HookExecutor")
     @mock.patch("rally.task.engine.time.time")
@@ -673,6 +743,8 @@ class ResultConsumerTestCase(test.TestCase):
         mock_task_get_status.return_value = consts.TaskStatus.RUNNING
         key = {"kw": {"fake": 2, "hooks": []}, "name": "fake", "pos": 0}
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         runner = mock.MagicMock()
         events = [
             {"type": "iteration", "value": 1},
@@ -682,7 +754,8 @@ class ResultConsumerTestCase(test.TestCase):
         runner.result_queue = collections.deque()
         runner.event_queue = collections.deque(events)
 
-        consumer_obj = engine.ResultConsumer(key, task, runner, False)
+        consumer_obj = engine.ResultConsumer(key, task, subtask,
+                                             workload, runner, False)
         stop_event = threading.Event()
 
         def set_stop_event(event_type, value):
@@ -700,15 +773,13 @@ class ResultConsumerTestCase(test.TestCase):
             mock.call(event_type="iteration", value=3)
         ])
 
-        task.append_results.assert_called_once_with(
-            key, {
-                "raw": [],
-                "full_duration": 1,
-                "sla": mock_sla_results,
-                "hooks": mock_hook_results,
-                "load_duration": 0
-            }
-        )
+        self.assertFalse(workload.add_workload_data.called)
+        workload.set_results.assert_called_once_with({
+            "full_duration": 1,
+            "sla": mock_sla_results,
+            "hooks": mock_hook_results,
+            "load_duration": 0
+        })
 
     @mock.patch("rally.task.engine.threading.Thread")
     @mock.patch("rally.task.engine.threading.Event")
@@ -723,6 +794,8 @@ class ResultConsumerTestCase(test.TestCase):
         runner = mock.MagicMock()
         key = mock.MagicMock()
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         mock_task_get_status.side_effect = (consts.TaskStatus.RUNNING,
                                             consts.TaskStatus.RUNNING,
                                             consts.TaskStatus.ABORTING)
@@ -730,7 +803,7 @@ class ResultConsumerTestCase(test.TestCase):
         mock_event.return_value = mock_is_done
         mock_is_done.isSet.return_value = False
 
-        res = engine.ResultConsumer(key, task, runner, True)
+        res = engine.ResultConsumer(key, task, subtask, workload, runner, True)
         res.wait_and_abort()
 
         runner.abort.assert_called_with()
@@ -750,13 +823,15 @@ class ResultConsumerTestCase(test.TestCase):
         runner = mock.MagicMock()
         key = mock.MagicMock()
         task = mock.MagicMock()
+        subtask = mock.Mock(spec=objects.Subtask)
+        workload = mock.Mock(spec=objects.Workload)
         mock_task_get_status.return_value = consts.TaskStatus.RUNNING
         mock_is_done = mock.MagicMock()
         mock_event.return_value = mock_is_done
 
         mock_is_done.isSet.side_effect = [False, False, False, False, True]
 
-        res = engine.ResultConsumer(key, task, runner, True)
+        res = engine.ResultConsumer(key, task, subtask, workload, runner, True)
         res.wait_and_abort()
 
         # check method don't abort runner if task is not aborted
