@@ -26,7 +26,6 @@ from rally import consts
 from rally import exceptions
 import rally.osclients
 from rally.task import validation
-from rally.verification.tempest import tempest
 from tests.unit import test
 
 
@@ -269,7 +268,7 @@ class ValidatorsTestCase(test.TestCase):
                          result[1])
         mock_glance_image_transform.assert_called_once_with(
             clients=clients, resource_config="test")
-        clients.glance().images.get.assert_called_with(image="image_id")
+        clients.glance().images.get.assert_called_with("image_id")
 
     @mock.patch(MODULE + "openstack_types.GlanceImage.transform",
                 side_effect=exceptions.InvalidScenarioArgument)
@@ -535,75 +534,6 @@ class ValidatorsTestCase(test.TestCase):
         result = validator({"args": {"name": "custom"}}, clients, None)
         self.assertTrue(result.is_valid, result.msg)
 
-    def test_tempest_tests_exists_no_arg(self):
-        validator = self._unwrap_validator(validation.tempest_tests_exists)
-        result = validator({}, None, None)
-        self.assertFalse(result.is_valid, result.msg)
-
-    @mock.patch(MODULE + "tempest.Tempest")
-    def test_tempest_tests_exists(self, mock_tempest):
-        mock_tempest().is_installed.return_value = False
-        mock_tempest().is_configured.return_value = False
-        mock_tempest().discover_tests.return_value = set([
-            "tempest.api.a", "tempest.api.b", "tempest.api.c"])
-
-        deployment = {"uuid": "someuuid"}
-        validator = self._unwrap_validator(validation.tempest_tests_exists)
-
-        result = validator({"args": {"test_name": "a"}}, None, deployment)
-        self.assertTrue(result.is_valid, result.msg)
-        mock_tempest().is_installed.assert_called_once_with()
-        mock_tempest().is_configured.assert_called_once_with()
-        mock_tempest().discover_tests.assert_called_once_with()
-
-        result = validator({"args": {"test_name": "d"}}, None, deployment)
-        self.assertFalse(result.is_valid, result.msg)
-
-        result = validator({"args": {"test_name": "tempest.api.a"}}, None,
-                           deployment)
-        self.assertTrue(result.is_valid, result.msg)
-        result = validator({"args": {"test_name": "tempest.api.d"}}, None,
-                           deployment)
-        self.assertFalse(result.is_valid, result.msg)
-
-        result = validator({"args": {"test_names": ["tempest.api.a", "b"]}},
-                           None, deployment)
-        self.assertTrue(result.is_valid, result.msg)
-
-        result = validator({"args": {"test_names": ["tempest.api.j", "e"]}},
-                           None, deployment)
-        self.assertFalse(result.is_valid, result.msg)
-
-    @mock.patch(MODULE + "tempest.Tempest")
-    def test_tempest_tests_exists_tempest_installation_failed(self,
-                                                              mock_tempest):
-        mock_tempest().is_installed.return_value = False
-        mock_tempest().install.side_effect = tempest.TempestSetupFailure
-
-        deployment = {"uuid": "someuuid"}
-        validator = self._unwrap_validator(validation.tempest_tests_exists)
-
-        result = validator({"args": {"test_name": "a"}}, None, deployment)
-        self.assertFalse(result.is_valid, result.msg)
-        mock_tempest().is_installed.assert_called_once_with()
-
-    def test_tempest_set_exists_missing_args(self):
-        validator = self._unwrap_validator(validation.tempest_set_exists)
-        result = validator({}, None, None)
-        self.assertFalse(result.is_valid, result.msg)
-
-    def test_tempest_set_exists(self):
-        validator = self._unwrap_validator(validation.tempest_set_exists)
-        sets = list(list(consts.TempestTestsSets) +
-                    list(consts.TempestTestsAPI))
-        result = validator(
-            {"args": {"set_name": sets[0]}}, None, None)
-        self.assertTrue(result.is_valid, result.msg)
-
-        result = validator(
-            {"args": {"set_name": "lol"}}, None, None)
-        self.assertFalse(result.is_valid, result.msg)
-
     def test_required_parameters(self):
         validator = self._unwrap_validator(validation.required_parameters,
                                            "a", "b")
@@ -974,3 +904,44 @@ class ValidatorsTestCase(test.TestCase):
         config = {"context": {"api_versions": {"nova": {"version": 2}}}}
         self.assertEqual(validator(config, clients, None).is_valid,
                          valid)
+
+    @mock.patch(
+        "yaml.safe_load",
+        return_value={
+            "version": "2.0",
+            "name": "wb",
+            "workflows": {
+                "wf1": {
+                    "type": "direct",
+                    "tasks": {
+                        "t1": {
+                            "action": "std.noop"
+                        }
+                    }
+                }
+            }
+        }
+    )
+    @mock.patch(MODULE + "os.access")
+    @mock.patch(MODULE + "open")
+    def test_workbook_contains_workflow(self, mock_open, mock_access,
+                                        mock_safe_load):
+
+        validator = self._unwrap_validator(
+            validation.workbook_contains_workflow, "definition",
+            "workflow_name")
+        clients = mock.MagicMock()
+
+        context = {
+            "args": {
+                "definition": "fake_path1",
+                "workflow_name": "wf1"
+            }
+        }
+
+        result = validator(context, clients, None)
+        self.assertTrue(result.is_valid)
+
+        self.assertEqual(1, mock_open.called)
+        self.assertEqual(1, mock_access.called)
+        self.assertEqual(1, mock_safe_load.called)
