@@ -365,7 +365,28 @@ class OSClientsTestCase(test.TestCase):
             self.assertEqual(fake_neutron, client)
             kw = {
                 "session": mock_keystoneauth1.session.Session(),
-                "endpoint_url": mock_neutron__get_endpoint.return_value}
+                "endpoint_override": mock_neutron__get_endpoint.return_value}
+            mock_neutron.client.Client.assert_called_once_with("2.0", **kw)
+            self.assertEqual(fake_neutron, self.clients.cache["neutron"])
+
+    @mock.patch("rally.osclients.Neutron._get_endpoint")
+    def test_neutron_endpoint_type(self, mock_neutron__get_endpoint):
+        fake_neutron = fakes.FakeNeutronClient()
+        mock_neutron__get_endpoint.return_value = "http://fake.to:2/fake"
+        mock_neutron = mock.MagicMock()
+        mock_keystoneauth1 = mock.MagicMock()
+        mock_neutron.client.Client.return_value = fake_neutron
+        self.assertNotIn("neutron", self.clients.cache)
+        self.credential.endpoint_type = "internal"
+        with mock.patch.dict("sys.modules",
+                             {"neutronclient.neutron": mock_neutron,
+                              "keystoneauth1": mock_keystoneauth1}):
+            client = self.clients.neutron()
+            self.assertEqual(fake_neutron, client)
+            kw = {
+                "session": mock_keystoneauth1.session.Session(),
+                "endpoint_override": mock_neutron__get_endpoint.return_value,
+                "endpoint_type": "internal"}
             mock_neutron.client.Client.assert_called_once_with("2.0", **kw)
             self.assertEqual(fake_neutron, self.clients.cache["neutron"])
 
@@ -383,7 +404,7 @@ class OSClientsTestCase(test.TestCase):
             client = self.clients.glance()
             self.assertEqual(fake_glance, client)
             kw = {
-                "version": "1",
+                "version": "2",
                 "session": mock_keystoneauth1.session.Session(),
                 "endpoint_override": mock_glance__get_endpoint.return_value}
             mock_glance.Client.assert_called_once_with(**kw)
@@ -739,23 +760,6 @@ class OSClientsTestCase(test.TestCase):
                 key += "%s" % {"version": version}
             self.assertEqual(fake_designate, self.clients.cache[key])
 
-    @mock.patch("rally.osclients.Keystone.get_session")
-    def test_cue(self, mock_keystone_get_session):
-        fake_cue = fakes.FakeCueClient()
-        mock_cue = mock.MagicMock()
-        mock_cue.client.Client = mock.MagicMock(return_value=fake_cue)
-        mock_keystone_get_session.return_value = ("fake_session",
-                                                  "fake_auth_plugin")
-        self.assertNotIn("cue", self.clients.cache)
-        with mock.patch.dict("sys.modules", {"cueclient": mock_cue,
-                                             "cueclient.v1": mock_cue}):
-            client = self.clients.cue()
-            self.assertEqual(fake_cue, client)
-            mock_cue.client.Client.assert_called_once_with(
-                interface=self.credential.endpoint_type,
-                session="fake_session")
-            self.assertEqual(fake_cue, self.clients.cache["cue"])
-
     def test_senlin(self):
         mock_senlin = mock.MagicMock()
         self.assertNotIn("senlin", self.clients.cache)
